@@ -63,39 +63,22 @@ bool show_text_list = false;
 bool show_text_list_with_font = false;
 poppler::page::text_layout_enum show_text_layout = poppler::page::physical_layout;
 
-static const ArgDesc the_args[] = {
-    { "--show-all",            argFlag,  &show_all,            0,
-      "show all the available information" },
-    { "--show-info",           argFlag,  &show_info,           0,
-      "show general document information" },
-    { "--show-perm",           argFlag,  &show_perm,           0,
-      "show document permissions" },
-    { "--show-metadata",       argFlag,  &show_metadata,       0,
-      "show document metadata" },
-    { "--show-toc",            argFlag,  &show_toc,            0,
-      "show the TOC" },
-    { "--show-fonts",          argFlag,  &show_fonts,          0,
-      "show the document fonts" },
-    { "--show-embedded-files", argFlag,  &show_embedded_files, 0,
-      "show the document-level embedded files" },
-    { "--show-pages",          argFlag,  &show_pages,          0,
-      "show pages information" },
-    { "--show-destinations",   argFlag,  &show_destinations,   0,
-      "show named destinations" },
-    { "--show-text",           argString, &show_text,          sizeof(show_text),
-      "show text (physical|raw|none) extracted from all pages" },
-    { "--show-text-list",      argFlag, &show_text_list,       0,
-      "show text list (experimental)" },
-    { "--show-text-list-with-font",  argFlag, &show_text_list_with_font, 0,
-      "show text list with font info (experimental)" },
-    { "-h",                    argFlag,  &show_help,           0,
-      "print usage information" },
-    { "--help",                argFlag,  &show_help,           0,
-      "print usage information" },
-    { "--version",             argFlag,  &show_version,        0,
-      "print poppler version" },
-    { nullptr, argFlag, nullptr, 0, nullptr }
-};
+static const ArgDesc the_args[] = { { "--show-all", argFlag, &show_all, 0, "show all the available information" },
+                                    { "--show-info", argFlag, &show_info, 0, "show general document information" },
+                                    { "--show-perm", argFlag, &show_perm, 0, "show document permissions" },
+                                    { "--show-metadata", argFlag, &show_metadata, 0, "show document metadata" },
+                                    { "--show-toc", argFlag, &show_toc, 0, "show the TOC" },
+                                    { "--show-fonts", argFlag, &show_fonts, 0, "show the document fonts" },
+                                    { "--show-embedded-files", argFlag, &show_embedded_files, 0, "show the document-level embedded files" },
+                                    { "--show-pages", argFlag, &show_pages, 0, "show pages information" },
+                                    { "--show-destinations", argFlag, &show_destinations, 0, "show named destinations" },
+                                    { "--show-text", argString, &show_text, sizeof(show_text), "show text (physical|raw|none) extracted from all pages" },
+                                    { "--show-text-list", argFlag, &show_text_list, 0, "show text list (experimental)" },
+                                    { "--show-text-list-with-font", argFlag, &show_text_list_with_font, 0, "show text list with font info (experimental)" },
+                                    { "-h", argFlag, &show_help, 0, "print usage information" },
+                                    { "--help", argFlag, &show_help, 0, "print usage information" },
+                                    { "--version", argFlag, &show_version, 0, "print poppler version" },
+                                    { nullptr, argFlag, nullptr, 0, nullptr } };
 
 static void error(const std::string &msg)
 {
@@ -104,7 +87,7 @@ static void error(const std::string &msg)
     exit(1);
 }
 
-static std::ostream& operator<<(std::ostream& stream, const poppler::ustring &str)
+static std::ostream &operator<<(std::ostream &stream, const poppler::ustring &str)
 {
     const poppler::byte_array ba = str.to_utf8();
     for (const char c : ba) {
@@ -169,20 +152,22 @@ static std::string out_page_orientation(poppler::page::orientation_enum o)
 
 static std::string out_font_info_type(poppler::font_info::type_enum t)
 {
-#define OUT_FONT_TYPE(thetype) case poppler::font_info::thetype: return #thetype
+#define OUT_FONT_TYPE(thetype)                                                                                                                                                                                                                 \
+    case poppler::font_info::thetype:                                                                                                                                                                                                          \
+        return #thetype
     switch (t) {
-    OUT_FONT_TYPE(unknown);
-    OUT_FONT_TYPE(type1);
-    OUT_FONT_TYPE(type1c);
-    OUT_FONT_TYPE(type1c_ot);
-    OUT_FONT_TYPE(type3);
-    OUT_FONT_TYPE(truetype);
-    OUT_FONT_TYPE(truetype_ot);
-    OUT_FONT_TYPE(cid_type0);
-    OUT_FONT_TYPE(cid_type0c);
-    OUT_FONT_TYPE(cid_type0c_ot);
-    OUT_FONT_TYPE(cid_truetype);
-    OUT_FONT_TYPE(cid_truetype_ot);
+        OUT_FONT_TYPE(unknown);
+        OUT_FONT_TYPE(type1);
+        OUT_FONT_TYPE(type1c);
+        OUT_FONT_TYPE(type1c_ot);
+        OUT_FONT_TYPE(type3);
+        OUT_FONT_TYPE(truetype);
+        OUT_FONT_TYPE(truetype_ot);
+        OUT_FONT_TYPE(cid_type0);
+        OUT_FONT_TYPE(cid_type0c);
+        OUT_FONT_TYPE(cid_type0c_ot);
+        OUT_FONT_TYPE(cid_truetype);
+        OUT_FONT_TYPE(cid_truetype_ot);
     }
     return "<unknown font type>";
 #undef OUT_FONT_TYPE
@@ -193,32 +178,38 @@ static void print_info(poppler::document *doc)
     std::cout << "Document information:" << std::endl;
     int major = 0, minor = 0;
     doc->get_pdf_version(&major, &minor);
-    std::cout << std::setw(out_width) << "PDF version" << ": " << major << "." << minor << std::endl;
+    std::cout << std::setw(out_width) << "PDF version"
+              << ": " << major << "." << minor << std::endl;
     std::string permanent_id, update_id;
     if (doc->get_pdf_id(&permanent_id, &update_id)) {
-        std::cout << std::setw(out_width) << "PDF IDs" << ": P: " << permanent_id << " - U: " << update_id << std::endl;
+        std::cout << std::setw(out_width) << "PDF IDs"
+                  << ": P: " << permanent_id << " - U: " << update_id << std::endl;
     } else {
-        std::cout << std::setw(out_width) << "PDF IDs" << ": <none>" << std::endl;
+        std::cout << std::setw(out_width) << "PDF IDs"
+                  << ": <none>" << std::endl;
     }
     const std::vector<std::string> keys = doc->info_keys();
     std::vector<std::string>::const_iterator key_it = keys.begin(), key_end = keys.end();
     for (; key_it != key_end; ++key_it) {
         std::cout << std::setw(out_width) << *key_it << ": " << doc->info_key(*key_it) << std::endl;
     }
-    std::cout << std::setw(out_width) << "Date (creation)" << ": " << out_date(doc->info_date("CreationDate")) << std::endl;
-    std::cout << std::setw(out_width) << "Date (modification)" << ": " << out_date(doc->info_date("ModDate")) << std::endl;
-    std::cout << std::setw(out_width) << "Number of pages" << ": " << doc->pages() << std::endl;
-    std::cout << std::setw(out_width) << "Linearized" << ": " << doc->is_linearized() << std::endl;
-    std::cout << std::setw(out_width) << "Encrypted" << ": " << doc->is_encrypted() << std::endl;
+    std::cout << std::setw(out_width) << "Date (creation)"
+              << ": " << out_date(doc->info_date("CreationDate")) << std::endl;
+    std::cout << std::setw(out_width) << "Date (modification)"
+              << ": " << out_date(doc->info_date("ModDate")) << std::endl;
+    std::cout << std::setw(out_width) << "Number of pages"
+              << ": " << doc->pages() << std::endl;
+    std::cout << std::setw(out_width) << "Linearized"
+              << ": " << doc->is_linearized() << std::endl;
+    std::cout << std::setw(out_width) << "Encrypted"
+              << ": " << doc->is_encrypted() << std::endl;
     std::cout << std::endl;
 }
 
 static void print_perm(poppler::document *doc)
 {
     std::cout << "Document permissions:" << std::endl;
-#define OUT_PERM(theperm) \
-    std::cout << std::setw(out_width) << #theperm << ": " \
-              << doc->has_permission(poppler::perm_##theperm) << std::endl
+#define OUT_PERM(theperm) std::cout << std::setw(out_width) << #theperm << ": " << doc->has_permission(poppler::perm_##theperm) << std::endl
     OUT_PERM(print);
     OUT_PERM(change);
     OUT_PERM(copy);
@@ -233,7 +224,8 @@ static void print_perm(poppler::document *doc)
 
 static void print_metadata(poppler::document *doc)
 {
-    std::cout << std::setw(out_width) << "Metadata" << ":" << std::endl
+    std::cout << std::setw(out_width) << "Metadata"
+              << ":" << std::endl
               << doc->metadata() << std::endl;
     std::cout << std::endl;
 }
@@ -241,8 +233,7 @@ static void print_metadata(poppler::document *doc)
 static void print_toc_item(poppler::toc_item *item, int indent)
 {
     std::cout << std::setw(indent * 2) << " "
-              << "+ " << item->title() << " (" << item->is_open() << ")"
-              << std::endl;
+              << "+ " << item->title() << " (" << item->is_open() << ")" << std::endl;
     poppler::toc_item::iterator it = item->children_begin(), it_end = item->children_end();
     for (; it != it_end; ++it) {
         print_toc_item(*it, indent + 1);
@@ -269,13 +260,8 @@ static void print_fonts(poppler::document *doc)
         const std::ios_base::fmtflags f = std::cout.flags();
         std::left(std::cout);
         for (; it != it_end; ++it) {
-            std::cout
-                << " " << std::setw(out_width + 10) << it->name()
-                << " " << std::setw(15) << out_font_info_type(it->type())
-                << " " << std::setw(5) << it->is_embedded()
-                << " " << std::setw(5) << it->is_subset()
-                << " " << it->file()
-                << std::endl;
+            std::cout << " " << std::setw(out_width + 10) << it->name() << " " << std::setw(15) << out_font_info_type(it->type()) << " " << std::setw(5) << it->is_embedded() << " " << std::setw(5) << it->is_subset() << " " << it->file()
+                      << std::endl;
         }
         std::cout.flags(f);
     } else {
@@ -294,23 +280,16 @@ static void print_embedded_files(poppler::document *doc)
         std::left(std::cout);
         for (; it != it_end; ++it) {
             poppler::embedded_file *f = *it;
-            std::cout
-                << " " << std::setw(out_width + 10) << f->name()
-                << " " << std::setw(10) << out_size(f->size())
-                << " " << std::setw(20) << out_date(f->creation_date())
-                << " " << std::setw(20) << out_date(f->modification_date())
-                << std::endl
-                << "     ";
+            std::cout << " " << std::setw(out_width + 10) << f->name() << " " << std::setw(10) << out_size(f->size()) << " " << std::setw(20) << out_date(f->creation_date()) << " " << std::setw(20) << out_date(f->modification_date())
+                      << std::endl
+                      << "     ";
             if (f->description().empty()) {
                 std::cout << "<no description>";
             } else {
                 std::cout << f->description();
             }
-            std::cout
-                << std::endl
-                << "     " << std::setw(35) << (f->checksum().empty() ? std::string("<no checksum>") : out_hex_string(f->checksum()))
-                << " " << (f->mime_type().empty() ? std::string("<no mime type>") : f->mime_type())
-                << std::endl;
+            std::cout << std::endl
+                      << "     " << std::setw(35) << (f->checksum().empty() ? std::string("<no checksum>") : out_hex_string(f->checksum())) << " " << (f->mime_type().empty() ? std::string("<no mime type>") : f->mime_type()) << std::endl;
         }
         std::cout.flags(flags);
     } else {
@@ -322,10 +301,14 @@ static void print_embedded_files(poppler::document *doc)
 static void print_page(poppler::page *p)
 {
     if (p) {
-        std::cout << std::setw(out_width) << "Rect" << ": " << p->page_rect() << std::endl;
-        std::cout << std::setw(out_width) << "Label" << ": " << p->label() << std::endl;
-        std::cout << std::setw(out_width) << "Duration" << ": " << p->duration() << std::endl;
-        std::cout << std::setw(out_width) << "Orientation" << ": " << out_page_orientation(p->orientation()) << std::endl;
+        std::cout << std::setw(out_width) << "Rect"
+                  << ": " << p->page_rect() << std::endl;
+        std::cout << std::setw(out_width) << "Label"
+                  << ": " << p->label() << std::endl;
+        std::cout << std::setw(out_width) << "Duration"
+                  << ": " << p->duration() << std::endl;
+        std::cout << std::setw(out_width) << "Orientation"
+                  << ": " << out_page_orientation(p->orientation()) << std::endl;
     } else {
         std::cout << std::setw(out_width) << "Broken Page. Could not be parsed" << std::endl;
     }
@@ -335,72 +318,73 @@ static void print_page(poppler::page *p)
 static void print_destination(const poppler::destination *d)
 {
     if (d) {
-        std::cout << std::setw(out_width) << "Type" << ": ";
+        std::cout << std::setw(out_width) << "Type"
+                  << ": ";
         switch (d->type()) {
         case poppler::destination::unknown:
             std::cout << "unknown" << std::endl;
             break;
         case poppler::destination::xyz:
             std::cout << "xyz" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl
-                      << std::setw(out_width)
-                      << "Left" << ": " << d->left() << std::endl
-                      << std::setw(out_width)
-                      << "Top" << ": " << d->top() << std::endl
-                      << std::setw(out_width)
-                      << "Zoom" << ": " << d->zoom() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl
+                      << std::setw(out_width) << "Left"
+                      << ": " << d->left() << std::endl
+                      << std::setw(out_width) << "Top"
+                      << ": " << d->top() << std::endl
+                      << std::setw(out_width) << "Zoom"
+                      << ": " << d->zoom() << std::endl;
             break;
         case poppler::destination::fit:
             std::cout << "fit" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl;
             break;
         case poppler::destination::fit_h:
             std::cout << "fit_h" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl
-                      << std::setw(out_width)
-                      << "Top" << ": " << d->top() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl
+                      << std::setw(out_width) << "Top"
+                      << ": " << d->top() << std::endl;
             break;
         case poppler::destination::fit_v:
             std::cout << "fit_v" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl
-                      << std::setw(out_width)
-                      << "Left" << ": " << d->left() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl
+                      << std::setw(out_width) << "Left"
+                      << ": " << d->left() << std::endl;
             break;
         case poppler::destination::fit_r:
             std::cout << "fit_r" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl
-                      << std::setw(out_width)
-                      << "Left" << ": " << d->left() << std::endl
-                      << std::setw(out_width)
-                      << "Bottom" << ": " << d->bottom() << std::endl
-                      << std::setw(out_width)
-                      << "Right" << ": " << d->right() << std::endl
-                      << std::setw(out_width)
-                      << "Top" << ": " << d->top() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl
+                      << std::setw(out_width) << "Left"
+                      << ": " << d->left() << std::endl
+                      << std::setw(out_width) << "Bottom"
+                      << ": " << d->bottom() << std::endl
+                      << std::setw(out_width) << "Right"
+                      << ": " << d->right() << std::endl
+                      << std::setw(out_width) << "Top"
+                      << ": " << d->top() << std::endl;
             break;
         case poppler::destination::fit_b:
             std::cout << "fit_b" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl;
             break;
         case poppler::destination::fit_b_h:
             std::cout << "fit_b_h" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl
-                      << std::setw(out_width)
-                      << "Top" << ": " << d->top() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl
+                      << std::setw(out_width) << "Top"
+                      << ": " << d->top() << std::endl;
             break;
         case poppler::destination::fit_b_v:
             std::cout << "fit_b_v" << std::endl
-                      << std::setw(out_width)
-                      << "Page" << ": " << d->page_number() << std::endl
-                      << std::setw(out_width)
-                      << "Left" << ": " << d->left() << std::endl;
+                      << std::setw(out_width) << "Page"
+                      << ": " << d->page_number() << std::endl
+                      << std::setw(out_width) << "Left"
+                      << ": " << d->left() << std::endl;
             break;
         default:
             std::cout << "error" << std::endl;
@@ -438,18 +422,17 @@ static void print_page_text_list(poppler::page *p, int opt_flag = 0)
         std::string font_name = text.get_font_name();
         std::cout << "[" << ustr << "] @ ";
         std::cout << "( x=" << bbox.x() << " y=" << bbox.y() << " w=" << bbox.width() << " h=" << bbox.height() << " )";
-        if (text.has_font_info())
+        if (text.has_font_info()) {
             std::cout << "( fontname=" << font_name << " fontsize=" << font_size << " wmode=" << wmode << " )";
+        }
         std::cout << std::endl;
     }
     std::cout << "---" << std::endl;
 }
 
-
 int main(int argc, char *argv[])
 {
-    if (!parseArgs(the_args, &argc, argv)
-        || argc < 2 || show_help) {
+    if (!parseArgs(the_args, &argc, argv) || argc < 2 || show_help) {
         printUsage(argv[0], "DOCUMENT", the_args);
         exit(1);
     }
@@ -489,10 +472,10 @@ int main(int argc, char *argv[])
     }
 
     if (show_version) {
-        std::cout << std::setw(out_width) << "Compiled" << ": poppler-cpp "
-                  << POPPLER_VERSION << std::endl
-                  << std::setw(out_width) << "Running" << ": poppler-cpp "
-                  << poppler::version_string() << std::endl;
+        std::cout << std::setw(out_width) << "Compiled"
+                  << ": poppler-cpp " << POPPLER_VERSION << std::endl
+                  << std::setw(out_width) << "Running"
+                  << ": poppler-cpp " << poppler::version_string() << std::endl;
     }
     if (show_info) {
         print_info(doc.get());
@@ -523,11 +506,12 @@ int main(int argc, char *argv[])
     }
     if (show_destinations) {
         auto map = doc->create_destination_map();
-        for (const auto &pair: map) {
+        for (const auto &pair : map) {
             std::string s = pair.first;
-            for (auto &c: s) {
-                if (c < 0x20 || c>0x7e )
+            for (auto &c : s) {
+                if (c < 0x20 || c > 0x7e) {
                     c = '.';
+                }
             }
             std::cout << "Named destination \"" << s << "\":" << std::endl;
             print_destination(&pair.second);
@@ -546,10 +530,11 @@ int main(int argc, char *argv[])
         for (int i = 0; i < pages; ++i) {
             std::cout << "Page " << (i + 1) << "/" << pages << ":" << std::endl;
             std::unique_ptr<poppler::page> p(doc->create_page(i));
-            if (show_text_list_with_font)
+            if (show_text_list_with_font) {
                 print_page_text_list(p.get(), poppler::page::text_list_include_font);
-            else
+            } else {
                 print_page_text_list(p.get(), 0);
+            }
         }
     }
 
