@@ -490,8 +490,9 @@ PopplerAnnot *_poppler_annot_screen_new(PopplerDocument *doc, Annot *annot)
     poppler_annot = _poppler_create_annot(POPPLER_TYPE_ANNOT_SCREEN, annot);
     annot_screen = static_cast<AnnotScreen *>(poppler_annot->annot);
     action = annot_screen->getAction();
-    if (action)
+    if (action) {
         POPPLER_ANNOT_SCREEN(poppler_annot)->action = _poppler_action_new(doc, action, nullptr);
+    }
 
     return poppler_annot;
 }
@@ -700,17 +701,14 @@ gchar *poppler_annot_get_contents(PopplerAnnot *poppler_annot)
  **/
 void poppler_annot_set_contents(PopplerAnnot *poppler_annot, const gchar *contents)
 {
-    GooString *goo_tmp;
     gchar *tmp;
     gsize length = 0;
 
     g_return_if_fail(POPPLER_IS_ANNOT(poppler_annot));
 
     tmp = contents ? g_convert(contents, -1, "UTF-16BE", "UTF-8", nullptr, &length, nullptr) : nullptr;
-    goo_tmp = new GooString(tmp, length);
+    poppler_annot->annot->setContents(std::make_unique<GooString>(tmp, length));
     g_free(tmp);
-    poppler_annot->annot->setContents(goo_tmp);
-    delete (goo_tmp);
 }
 
 /**
@@ -785,8 +783,9 @@ void poppler_annot_set_flags(PopplerAnnot *poppler_annot, PopplerAnnotFlag flags
 {
     g_return_if_fail(POPPLER_IS_ANNOT(poppler_annot));
 
-    if (poppler_annot_get_flags(poppler_annot) == flags)
+    if (poppler_annot_get_flags(poppler_annot) == flags) {
         return;
+    }
 
     poppler_annot->annot->setFlags((guint)flags);
 }
@@ -827,8 +826,9 @@ static PopplerColor *create_poppler_color_from_annot_color(AnnotColor *color)
 
 static std::unique_ptr<AnnotColor> create_annot_color_from_poppler_color(PopplerColor *poppler_color)
 {
-    if (!poppler_color)
+    if (!poppler_color) {
         return nullptr;
+    }
 
     return std::make_unique<AnnotColor>((double)poppler_color->red / 65535, (double)poppler_color->green / 65535, (double)poppler_color->blue / 65535);
 }
@@ -898,8 +898,9 @@ const PDFRectangle *_poppler_annot_get_cropbox_and_page(PopplerAnnot *poppler_an
 
         page = poppler_annot->annot->getDoc()->getPage(page_index);
         if (page) {
-            if (page_out)
+            if (page_out) {
                 *page_out = page;
+            }
 
             return page->getCropBox();
         }
@@ -927,7 +928,6 @@ const PDFRectangle *_poppler_annot_get_cropbox(PopplerAnnot *poppler_annot)
  */
 void poppler_annot_get_rectangle(PopplerAnnot *poppler_annot, PopplerRectangle *poppler_rect)
 {
-    PDFRectangle *annot_rect;
     const PDFRectangle *crop_box;
     PDFRectangle zerobox;
     Page *page = nullptr;
@@ -941,11 +941,11 @@ void poppler_annot_get_rectangle(PopplerAnnot *poppler_annot, PopplerRectangle *
         crop_box = &zerobox;
     }
 
-    annot_rect = poppler_annot->annot->getRect();
-    poppler_rect->x1 = annot_rect->x1 - crop_box->x1;
-    poppler_rect->x2 = annot_rect->x2 - crop_box->x1;
-    poppler_rect->y1 = annot_rect->y1 - crop_box->y1;
-    poppler_rect->y2 = annot_rect->y2 - crop_box->y1;
+    const PDFRectangle &annot_rect = poppler_annot->annot->getRect();
+    poppler_rect->x1 = annot_rect.x1 - crop_box->x1;
+    poppler_rect->x2 = annot_rect.x2 - crop_box->x1;
+    poppler_rect->y1 = annot_rect.y1 - crop_box->y1;
+    poppler_rect->y2 = annot_rect.y2 - crop_box->y1;
 }
 
 /**
@@ -1023,7 +1023,6 @@ gchar *poppler_annot_markup_get_label(PopplerAnnotMarkup *poppler_annot)
 void poppler_annot_markup_set_label(PopplerAnnotMarkup *poppler_annot, const gchar *label)
 {
     AnnotMarkup *annot;
-    GooString *goo_tmp;
     gchar *tmp;
     gsize length = 0;
 
@@ -1032,10 +1031,8 @@ void poppler_annot_markup_set_label(PopplerAnnotMarkup *poppler_annot, const gch
     annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT(poppler_annot)->annot);
 
     tmp = label ? g_convert(label, -1, "UTF-16BE", "UTF-8", nullptr, &length, nullptr) : nullptr;
-    goo_tmp = new GooString(tmp, length);
+    annot->setLabel(std::make_unique<GooString>(tmp, length));
     g_free(tmp);
-    annot->setLabel(goo_tmp);
-    delete goo_tmp;
 }
 
 /**
@@ -1098,8 +1095,9 @@ gboolean poppler_annot_markup_get_popup_is_open(PopplerAnnotMarkup *poppler_anno
 
     annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT(poppler_annot)->annot);
 
-    if ((annot_popup = annot->getPopup()))
+    if ((annot_popup = annot->getPopup())) {
         return annot_popup->getOpen();
+    }
 
     return FALSE;
 }
@@ -1123,11 +1121,13 @@ void poppler_annot_markup_set_popup_is_open(PopplerAnnotMarkup *poppler_annot, g
     annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT(poppler_annot)->annot);
 
     annot_popup = annot->getPopup();
-    if (!annot_popup)
+    if (!annot_popup) {
         return;
+    }
 
-    if (annot_popup->getOpen() != is_open)
+    if (annot_popup->getOpen() != is_open) {
         annot_popup->setOpen(is_open);
+    }
 }
 
 /**
@@ -1145,21 +1145,21 @@ gboolean poppler_annot_markup_get_popup_rectangle(PopplerAnnotMarkup *poppler_an
 {
     AnnotMarkup *annot;
     Annot *annot_popup;
-    PDFRectangle *annot_rect;
 
     g_return_val_if_fail(POPPLER_IS_ANNOT_MARKUP(poppler_annot), FALSE);
     g_return_val_if_fail(poppler_rect != nullptr, FALSE);
 
     annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT(poppler_annot)->annot);
     annot_popup = annot->getPopup();
-    if (!annot_popup)
+    if (!annot_popup) {
         return FALSE;
+    }
 
-    annot_rect = annot_popup->getRect();
-    poppler_rect->x1 = annot_rect->x1;
-    poppler_rect->x2 = annot_rect->x2;
-    poppler_rect->y1 = annot_rect->y1;
-    poppler_rect->y2 = annot_rect->y2;
+    const PDFRectangle &annot_rect = annot_popup->getRect();
+    poppler_rect->x1 = annot_rect.x1;
+    poppler_rect->x2 = annot_rect.x2;
+    poppler_rect->y1 = annot_rect.y1;
+    poppler_rect->y2 = annot_rect.y2;
 
     return TRUE;
 }
@@ -1186,8 +1186,9 @@ void poppler_annot_markup_set_popup_rectangle(PopplerAnnotMarkup *poppler_annot,
 
     annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT(poppler_annot)->annot);
     annot_popup = annot->getPopup();
-    if (!annot_popup)
+    if (!annot_popup) {
         return;
+    }
 
     annot_popup->setRect(poppler_rect->x1, poppler_rect->y1, poppler_rect->x2, poppler_rect->y2);
 }
@@ -1252,8 +1253,9 @@ GDate *poppler_annot_markup_get_date(PopplerAnnotMarkup *poppler_annot)
 
     annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT(poppler_annot)->annot);
     annot_date = annot->getDate();
-    if (!annot_date)
+    if (!annot_date) {
         return nullptr;
+    }
 
     if (_poppler_convert_pdf_date_to_gtime(annot_date, &timet)) {
         GDate *date;
@@ -1585,11 +1587,11 @@ PopplerAnnotFreeTextQuadding poppler_annot_free_text_get_quadding(PopplerAnnotFr
     annot = static_cast<AnnotFreeText *>(POPPLER_ANNOT(poppler_annot)->annot);
 
     switch (annot->getQuadding()) {
-    case AnnotFreeText::quaddingLeftJustified:
+    case VariableTextQuadding::leftJustified:
         return POPPLER_ANNOT_FREE_TEXT_QUADDING_LEFT_JUSTIFIED;
-    case AnnotFreeText::quaddingCentered:
+    case VariableTextQuadding::centered:
         return POPPLER_ANNOT_FREE_TEXT_QUADDING_CENTERED;
-    case AnnotFreeText::quaddingRightJustified:
+    case VariableTextQuadding::rightJustified:
         return POPPLER_ANNOT_FREE_TEXT_QUADDING_RIGHT_JUSTIFIED;
     default:
         g_warning("Unsupported Annot Free Text Quadding");
