@@ -73,8 +73,9 @@ std::vector<FontInfo *> FontInfoScanner::scan(int nPages)
     std::unique_ptr<XRef> xrefA(doc->getXRef()->copy());
     for (int pg = currentPage; pg < lastPage; ++pg) {
         page = doc->getPage(pg);
-        if (!page)
+        if (!page) {
             continue;
+        }
 
         if ((resDict = page->getResourceDictCopy(xrefA.get()))) {
             scanFonts(xrefA.get(), resDict, &result);
@@ -97,7 +98,6 @@ std::vector<FontInfo *> FontInfoScanner::scan(int nPages)
 void FontInfoScanner::scanFonts(XRef *xrefA, Dict *resDict, std::vector<FontInfo *> *fontsList)
 {
     GfxFontDict *gfxFontDict;
-    GfxFont *font;
 
     // scan the fonts in this resource dictionary
     gfxFontDict = nullptr;
@@ -113,12 +113,12 @@ void FontInfoScanner::scanFonts(XRef *xrefA, Dict *resDict, std::vector<FontInfo
     }
     if (gfxFontDict) {
         for (int i = 0; i < gfxFontDict->getNumFonts(); ++i) {
-            if ((font = gfxFontDict->getFont(i))) {
+            if (const std::shared_ptr<GfxFont> &font = gfxFontDict->getFont(i)) {
                 Ref fontRef = *font->getID();
 
                 // add this font to the list if not already found
                 if (fonts.insert(fontRef.num).second) {
-                    fontsList->push_back(new FontInfo(font, xrefA));
+                    fontsList->push_back(new FontInfo(font.get(), xrefA));
                 }
             }
         }
@@ -162,14 +162,12 @@ void FontInfoScanner::scanFonts(XRef *xrefA, Dict *resDict, std::vector<FontInfo
 
 FontInfo::FontInfo(GfxFont *font, XRef *xref)
 {
-    const GooString *origName;
-
     fontRef = *font->getID();
 
     // font name
-    origName = font->getName();
-    if (origName != nullptr) {
-        name = font->getName()->toStr();
+    const std::optional<std::string> &origName = font->getName();
+    if (origName) {
+        name = *font->getName();
     }
 
     // font type
@@ -187,10 +185,12 @@ FontInfo::FontInfo(GfxFont *font, XRef *xref)
         int dummy2;
         GooString substituteNameAux;
         std::unique_ptr<GooString> tmpFile(globalParams->findSystemFontFile(font, &dummy, &dummy2, &substituteNameAux));
-        if (tmpFile)
+        if (tmpFile) {
             file = tmpFile->toStr();
-        if (substituteNameAux.getLength() > 0)
+        }
+        if (substituteNameAux.getLength() > 0) {
             substituteName = substituteNameAux.toStr();
+        }
     }
     encoding = font->getEncodingName();
 
