@@ -42,8 +42,9 @@
 // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 // Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2020 Kai Pastor <dg0yt@darc.de>
-// Copyright (C) 2021 Stefan Löffler <st.loeffler@gmail.com>
+// Copyright (C) 2021, 2022 Stefan Löffler <st.loeffler@gmail.com>
 // Copyright (C) 2021 sunderme <sunderme@gmx.de>
+// Copyright (C) 2022 Even Rouault <even.rouault@spatialys.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -122,38 +123,38 @@ BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
 }
 }
 
-static void get_poppler_localdir(char *retval, const char *suffix)
+static std::string get_poppler_localdir(const std::string &suffix)
 {
-    unsigned char *p;
+    const std::string binSuffix("\\bin");
+    std::string retval(MAX_PATH, '\0');
 
-    if (!GetModuleFileNameA(hmodule, (CHAR *)retval, sizeof(retval) - 20)) {
-        strcpy(retval, POPPLER_DATADIR);
-        return;
+    if (!GetModuleFileNameA(hmodule, retval.data(), retval.size())) {
+        return POPPLER_DATADIR;
     }
 
-    p = _mbsrchr((unsigned char *)retval, '\\');
-    *p = '\0';
-    p = _mbsrchr((unsigned char *)retval, '\\');
-    if (p) {
-        if (stricmp((const char *)(p + 1), "bin") == 0)
-            *p = '\0';
+    const std::string::size_type p = retval.rfind('\\');
+    if (p != std::string::npos) {
+        retval.erase(p);
+        if (retval.size() > binSuffix.size() && stricmp(retval.substr(p - binSuffix.size()).c_str(), binSuffix.c_str()) == 0) {
+            retval.erase(p - binSuffix.size());
+        }
     }
-    strcat(retval, suffix);
+    retval += suffix;
+    retval.shrink_to_fit();
+    return retval;
 }
 
 static const char *get_poppler_datadir(void)
 {
-    static char retval[MAX_PATH];
+    static std::string retval;
     static bool beenhere = false;
 
-    if (beenhere)
-        return retval;
+    if (!beenhere) {
+        retval = get_poppler_localdir("\\share\\poppler");
+        beenhere = true;
+    }
 
-    get_poppler_localdir(retval, "\\share\\poppler");
-
-    beenhere = true;
-
-    return retval;
+    return retval.c_str();
 }
 
 #    undef POPPLER_DATADIR
@@ -161,17 +162,15 @@ static const char *get_poppler_datadir(void)
 
 static const char *get_poppler_fontsdir(void)
 {
-    static char retval[MAX_PATH];
+    static std::string retval;
     static bool beenhere = false;
 
-    if (beenhere)
-        return retval;
+    if (!beenhere) {
+        retval = get_poppler_localdir("\\share\\fonts");
+        beenhere = true;
+    }
 
-    get_poppler_localdir(retval, "\\share\\fonts");
-
-    beenhere = true;
-
-    return retval;
+    return retval.c_str();
 }
 #    undef POPPLER_FONTSDIR
 #    define POPPLER_FONTSDIR get_poppler_fontsdir()
@@ -252,7 +251,7 @@ public:
     ~SysFontList();
     SysFontList(const SysFontList &) = delete;
     SysFontList &operator=(const SysFontList &) = delete;
-    const SysFontInfo *find(const GooString *name, bool isFixedWidth, bool exact);
+    const SysFontInfo *find(const std::string &name, bool isFixedWidth, bool exact);
 
 #ifdef _WIN32
     void scanWindowsFonts(GooString *winFontDir);
@@ -277,13 +276,13 @@ SysFontList::~SysFontList()
     }
 }
 
-const SysFontInfo *SysFontList::find(const GooString *name, bool fixedWidth, bool exact)
+const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, bool exact)
 {
     GooString *name2;
     bool bold, italic, oblique;
     int n;
 
-    name2 = name->copy();
+    name2 = new GooString(name);
 
     // remove space, comma, dash chars
     {
@@ -390,9 +389,9 @@ const SysFontInfo *SysFontList::find(const GooString *name, bool fixedWidth, boo
     return fi;
 }
 
-#define globalParamsLocker() std::unique_lock<std::recursive_mutex> locker(mutex)
-#define unicodeMapCacheLocker() std::unique_lock<std::recursive_mutex> locker(unicodeMapCacheMutex)
-#define cMapCacheLocker() std::unique_lock<std::recursive_mutex> locker(cMapCacheMutex)
+#define globalParamsLocker() const std::scoped_lock locker(mutex)
+#define unicodeMapCacheLocker() const std::scoped_lock locker(unicodeMapCacheMutex)
+#define cMapCacheLocker() const std::scoped_lock locker(cMapCacheMutex)
 
 //------------------------------------------------------------------------
 // parsing
@@ -584,8 +583,9 @@ Unicode GlobalParams::mapNameToUnicodeAll(const char *charName)
 {
     // no need to lock - nameToUnicodeZapfDingbats and nameToUnicodeText are constant
     Unicode u = nameToUnicodeZapfDingbats->lookup(charName);
-    if (!u)
+    if (!u) {
         u = nameToUnicodeText->lookup(charName);
+    }
     return u;
 }
 
@@ -662,13 +662,15 @@ static bool findModifier(const char *name, const char *modifier, const char **st
 {
     const char *match;
 
-    if (name == nullptr)
+    if (name == nullptr) {
         return false;
+    }
 
     match = strstr(name, modifier);
     if (match) {
-        if (*start == nullptr || match < *start)
+        if (*start == nullptr || match < *start) {
             *start = match;
+        }
         return true;
     } else {
         return false;
@@ -683,28 +685,30 @@ static const char *getFontLang(const GfxFont *font)
     if (font->isCIDFont()) {
         const GooString *collection = ((GfxCIDFont *)font)->getCollection();
         if (collection) {
-            if (strcmp(collection->c_str(), "Adobe-GB1") == 0)
+            if (strcmp(collection->c_str(), "Adobe-GB1") == 0) {
                 lang = "zh-cn"; // Simplified Chinese
-            else if (strcmp(collection->c_str(), "Adobe-CNS1") == 0)
+            } else if (strcmp(collection->c_str(), "Adobe-CNS1") == 0) {
                 lang = "zh-tw"; // Traditional Chinese
-            else if (strcmp(collection->c_str(), "Adobe-Japan1") == 0)
+            } else if (strcmp(collection->c_str(), "Adobe-Japan1") == 0) {
                 lang = "ja"; // Japanese
-            else if (strcmp(collection->c_str(), "Adobe-Japan2") == 0)
+            } else if (strcmp(collection->c_str(), "Adobe-Japan2") == 0) {
                 lang = "ja"; // Japanese
-            else if (strcmp(collection->c_str(), "Adobe-Korea1") == 0)
+            } else if (strcmp(collection->c_str(), "Adobe-Korea1") == 0) {
                 lang = "ko"; // Korean
-            else if (strcmp(collection->c_str(), "Adobe-UCS") == 0)
+            } else if (strcmp(collection->c_str(), "Adobe-UCS") == 0) {
                 lang = "xx";
-            else if (strcmp(collection->c_str(), "Adobe-Identity") == 0)
+            } else if (strcmp(collection->c_str(), "Adobe-Identity") == 0) {
                 lang = "xx";
-            else {
+            } else {
                 error(errUnimplemented, -1, "Unknown CID font collection, please report to poppler bugzilla.");
                 lang = "xx";
             }
-        } else
+        } else {
             lang = "xx";
-    } else
+        }
+    } else {
         lang = "xx";
+    }
     return lang;
 }
 
@@ -719,31 +723,39 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
     char *fontName = strdup(((base14Name == nullptr) ? font->getNameWithoutSubsetTag() : base14Name->toStr()).c_str());
 
     const char *modifiers = strchr(fontName, ',');
-    if (modifiers == nullptr)
+    if (modifiers == nullptr) {
         modifiers = strchr(fontName, '-');
+    }
 
     // remove the - from the names, for some reason, Fontconfig does not
     // understand "MS-Mincho" but does with "MS Mincho"
     const int len = strlen(fontName);
-    for (int i = 0; i < len; i++)
+    for (int i = 0; i < len; i++) {
         fontName[i] = (fontName[i] == '-' ? ' ' : fontName[i]);
+    }
 
     start = nullptr;
     findModifier(modifiers, "Regular", &start);
     findModifier(modifiers, "Roman", &start);
 
-    if (findModifier(modifiers, "Oblique", &start))
+    if (findModifier(modifiers, "Oblique", &start)) {
         slant = FC_SLANT_OBLIQUE;
-    if (findModifier(modifiers, "Italic", &start))
+    }
+    if (findModifier(modifiers, "Italic", &start)) {
         slant = FC_SLANT_ITALIC;
-    if (findModifier(modifiers, "Bold", &start))
+    }
+    if (findModifier(modifiers, "Bold", &start)) {
         weight = FC_WEIGHT_BOLD;
-    if (findModifier(modifiers, "Light", &start))
+    }
+    if (findModifier(modifiers, "Light", &start)) {
         weight = FC_WEIGHT_LIGHT;
-    if (findModifier(modifiers, "Medium", &start))
+    }
+    if (findModifier(modifiers, "Medium", &start)) {
         weight = FC_WEIGHT_MEDIUM;
-    if (findModifier(modifiers, "Condensed", &start))
+    }
+    if (findModifier(modifiers, "Condensed", &start)) {
         width = FC_WIDTH_CONDENSED;
+    }
 
     if (start) {
         // There have been "modifiers" in the name, crop them to obtain
@@ -757,12 +769,15 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
     }
 
     // use font flags
-    if (font->isFixedWidth())
+    if (font->isFixedWidth()) {
         spacing = FC_MONO;
-    if (font->isBold())
+    }
+    if (font->isBold()) {
         weight = FC_WEIGHT_BOLD;
-    if (font->isItalic())
+    }
+    if (font->isItalic()) {
         slant = FC_SLANT_ITALIC;
+    }
 
     bool freeFamily = true;
     // if the FontDescriptor specified a family name use it
@@ -841,28 +856,33 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
     const char *lang = getFontLang(font);
 
     p = FcPatternBuild(nullptr, FC_FAMILY, FcTypeString, family, FC_LANG, FcTypeString, lang, NULL);
-    if (slant != -1)
+    if (slant != -1) {
         FcPatternAddInteger(p, FC_SLANT, slant);
-    if (weight != -1)
+    }
+    if (weight != -1) {
         FcPatternAddInteger(p, FC_WEIGHT, weight);
-    if (width != -1)
+    }
+    if (width != -1) {
         FcPatternAddInteger(p, FC_WIDTH, width);
-    if (spacing != -1)
+    }
+    if (spacing != -1) {
         FcPatternAddInteger(p, FC_SPACING, spacing);
+    }
 
-    if (freeFamily)
+    if (freeFamily) {
         free((char *)family);
+    }
     return p;
 }
 #endif
 
-GooString *GlobalParams::findFontFile(const GooString *fontName)
+GooString *GlobalParams::findFontFile(const std::string &fontName)
 {
     GooString *path = nullptr;
 
     setupBaseFonts(POPPLER_FONTSDIR);
     globalParamsLocker();
-    const auto fontFile = fontFiles.find(fontName->toStr());
+    const auto fontFile = fontFiles.find(fontName);
     if (fontFile != fontFiles.end()) {
         path = new GooString(fontFile->second);
     }
@@ -890,14 +910,15 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
     const SysFontInfo *fi = nullptr;
     FcPattern *p = nullptr;
     GooString *path = nullptr;
-    const GooString *fontName = font->getName();
+    const std::optional<std::string> &fontName = font->getName();
     GooString substituteName;
-    if (!fontName)
+    if (!fontName) {
         return nullptr;
+    }
 
     globalParamsLocker();
 
-    if ((fi = sysFonts->find(fontName, font->isFixedWidth(), true))) {
+    if ((fi = sysFonts->find(*fontName, font->isFixedWidth(), true))) {
         path = fi->path->copy();
         *type = fi->type;
         *fontNum = fi->fontNum;
@@ -911,13 +932,15 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
         FcLangSet *lb = nullptr;
         p = buildFcPattern(font, base14Name);
 
-        if (!p)
+        if (!p) {
             goto fin;
+        }
         FcConfigSubstitute(nullptr, p, FcMatchPattern);
         FcDefaultSubstitute(p);
         set = FcFontSort(nullptr, p, FcFalse, nullptr, &res);
-        if (!set)
+        if (!set) {
             goto fin;
+        }
 
         // find the language we want the font to support
         const char *lang = getFontLang(font);
@@ -934,8 +957,9 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
         while (fi == nullptr) {
             for (i = 0; i < set->nfont; ++i) {
                 res = FcPatternGetString(set->fonts[i], FC_FILE, 0, &s);
-                if (res != FcResultMatch || !s)
+                if (res != FcResultMatch || !s) {
                     continue;
+                }
                 if (lb != nullptr) {
                     FcLangSet *l;
                     res = FcPatternGetLangSet(set->fonts[i], FC_LANG, 0, &l);
@@ -965,8 +989,9 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
                     }
                 }
                 ext = strrchr((char *)s, '.');
-                if (!ext)
+                if (!ext) {
                     continue;
+                }
                 if (!strncasecmp(ext, ".ttf", 4) || !strncasecmp(ext, ".ttc", 4) || !strncasecmp(ext, ".otf", 4)) {
                     int weight, slant;
                     bool bold = font->isBold();
@@ -977,14 +1002,16 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
                     if (weight == FC_WEIGHT_DEMIBOLD || weight == FC_WEIGHT_BOLD || weight == FC_WEIGHT_EXTRABOLD || weight == FC_WEIGHT_BLACK) {
                         bold = true;
                     }
-                    if (slant == FC_SLANT_ITALIC)
+                    if (slant == FC_SLANT_ITALIC) {
                         italic = true;
-                    if (slant == FC_SLANT_OBLIQUE)
+                    }
+                    if (slant == FC_SLANT_OBLIQUE) {
                         oblique = true;
+                    }
                     *fontNum = 0;
                     *type = (!strncasecmp(ext, ".ttc", 4)) ? sysFontTTC : sysFontTTF;
                     FcPatternGetInteger(set->fonts[i], FC_INDEX, 0, fontNum);
-                    SysFontInfo *sfi = new SysFontInfo(fontName->copy(), bold, italic, oblique, font->isFixedWidth(), new GooString((char *)s), *type, *fontNum, substituteName.copy());
+                    SysFontInfo *sfi = new SysFontInfo(new GooString(*fontName), bold, italic, oblique, font->isFixedWidth(), new GooString((char *)s), *type, *fontNum, substituteName.copy());
                     sysFonts->addFcFont(sfi);
                     fi = sfi;
                     path = new GooString((char *)s);
@@ -998,19 +1025,22 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
                     if (weight == FC_WEIGHT_DEMIBOLD || weight == FC_WEIGHT_BOLD || weight == FC_WEIGHT_EXTRABOLD || weight == FC_WEIGHT_BLACK) {
                         bold = true;
                     }
-                    if (slant == FC_SLANT_ITALIC)
+                    if (slant == FC_SLANT_ITALIC) {
                         italic = true;
-                    if (slant == FC_SLANT_OBLIQUE)
+                    }
+                    if (slant == FC_SLANT_OBLIQUE) {
                         oblique = true;
+                    }
                     *fontNum = 0;
                     *type = (!strncasecmp(ext, ".pfa", 4)) ? sysFontPFA : sysFontPFB;
                     FcPatternGetInteger(set->fonts[i], FC_INDEX, 0, fontNum);
-                    SysFontInfo *sfi = new SysFontInfo(fontName->copy(), bold, italic, oblique, font->isFixedWidth(), new GooString((char *)s), *type, *fontNum, substituteName.copy());
+                    SysFontInfo *sfi = new SysFontInfo(new GooString(*fontName), bold, italic, oblique, font->isFixedWidth(), new GooString((char *)s), *type, *fontNum, substituteName.copy());
                     sysFonts->addFcFont(sfi);
                     fi = sfi;
                     path = new GooString((char *)s);
-                } else
+                } else {
                     continue;
+                }
                 break;
             }
             if (lb != nullptr) {
@@ -1023,7 +1053,7 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
         }
         FcFontSetDestroy(set);
     }
-    if (path == nullptr && (fi = sysFonts->find(fontName, font->isFixedWidth(), false))) {
+    if (path == nullptr && (fi = sysFonts->find(*fontName, font->isFixedWidth(), false))) {
         path = fi->path->copy();
         *type = fi->type;
         *fontNum = fi->fontNum;
@@ -1032,8 +1062,9 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
         substituteFontName->Set(substituteName.c_str());
     }
 fin:
-    if (p)
+    if (p) {
         FcPatternDestroy(p);
+    }
 
     return path;
 }
@@ -1043,12 +1074,12 @@ fin:
 
 GooString *GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont *font)
 {
-    return findFontFile(base14Name);
+    return findFontFile(base14Name->toStr());
 }
 #else
 GooString *GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont *font)
 {
-    return findFontFile(base14Name);
+    return findFontFile(base14Name->toStr());
 }
 
 static struct
@@ -1076,8 +1107,6 @@ static const char *displayFontDirs[] = { "/usr/share/ghostscript/fonts", "/usr/l
 
 void GlobalParams::setupBaseFonts(const char *dir)
 {
-    GooString *fontName;
-    GooString *fileName;
     FILE *f;
     int i, j;
 
@@ -1085,32 +1114,29 @@ void GlobalParams::setupBaseFonts(const char *dir)
         if (fontFiles.count(displayFontTab[i].name) > 0) {
             continue;
         }
-        fontName = new GooString(displayFontTab[i].name);
-        fileName = nullptr;
+        std::unique_ptr<GooString> fontName = std::make_unique<GooString>(displayFontTab[i].name);
+        std::unique_ptr<GooString> fileName;
         if (dir) {
-            fileName = appendToPath(new GooString(dir), displayFontTab[i].t1FileName);
+            fileName.reset(appendToPath(new GooString(dir), displayFontTab[i].t1FileName));
             if ((f = openFile(fileName->c_str(), "rb"))) {
                 fclose(f);
             } else {
-                delete fileName;
-                fileName = nullptr;
+                fileName.reset();
             }
         }
         for (j = 0; !fileName && displayFontDirs[j]; ++j) {
-            fileName = appendToPath(new GooString(displayFontDirs[j]), displayFontTab[i].t1FileName);
+            fileName.reset(appendToPath(new GooString(displayFontDirs[j]), displayFontTab[i].t1FileName));
             if ((f = openFile(fileName->c_str(), "rb"))) {
                 fclose(f);
             } else {
-                delete fileName;
-                fileName = nullptr;
+                fileName.reset();
             }
         }
         if (!fileName) {
             error(errConfig, -1, "No display font for '{0:s}'", displayFontTab[i].name);
-            delete fontName;
             continue;
         }
-        addFontFile(fontName, fileName);
+        addFontFile(fontName.get(), fileName.get());
     }
 }
 
@@ -1119,13 +1145,13 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
     const SysFontInfo *fi;
     GooString *path;
 
-    const GooString *fontName = font->getName();
+    const std::optional<std::string> &fontName = font->getName();
     if (!fontName)
         return nullptr;
 
     path = nullptr;
     globalParamsLocker();
-    if ((fi = sysFonts->find(fontName, font->isFixedWidth(), false))) {
+    if ((fi = sysFonts->find(*fontName, font->isFixedWidth(), false))) {
         path = fi->path->copy();
         *type = fi->type;
         *fontNum = fi->fontNum;
@@ -1198,7 +1224,7 @@ const UnicodeMap *GlobalParams::getUnicodeMap(const std::string &encodingName)
     return map;
 }
 
-CMap *GlobalParams::getCMap(const GooString *collection, const GooString *cMapName)
+std::shared_ptr<CMap> GlobalParams::getCMap(const GooString *collection, const GooString *cMapName)
 {
     cMapCacheLocker();
     return cMapCache->getCMap(collection, cMapName);
@@ -1258,7 +1284,7 @@ void GlobalParams::setErrQuiet(bool errQuietA)
 
 GlobalParamsIniter::GlobalParamsIniter(ErrorCallback errorCallback)
 {
-    std::lock_guard<std::mutex> lock { mutex };
+    const std::scoped_lock lock { mutex };
 
     if (count == 0) {
         globalParams = std::make_unique<GlobalParams>(!customDataDir.empty() ? customDataDir.c_str() : nullptr);
@@ -1271,7 +1297,7 @@ GlobalParamsIniter::GlobalParamsIniter(ErrorCallback errorCallback)
 
 GlobalParamsIniter::~GlobalParamsIniter()
 {
-    std::lock_guard<std::mutex> lock { mutex };
+    const std::scoped_lock lock { mutex };
 
     --count;
 
@@ -1282,7 +1308,7 @@ GlobalParamsIniter::~GlobalParamsIniter()
 
 bool GlobalParamsIniter::setCustomDataDir(const std::string &dir)
 {
-    std::lock_guard<std::mutex> lock { mutex };
+    const std::scoped_lock lock { mutex };
 
     if (count == 0) {
         customDataDir = dir;
