@@ -4,12 +4,13 @@
 //
 // A JPX stream decoder using OpenJPEG
 //
-// Copyright 2008-2010, 2012, 2017-2020 Albert Astals Cid <aacid@kde.org>
+// Copyright 2008-2010, 2012, 2017-2021 Albert Astals Cid <aacid@kde.org>
 // Copyright 2011 Daniel Glöckner <daniel-gl@gmx.net>
 // Copyright 2014, 2016 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright 2013, 2014 Adrian Johnson <ajohnson@redneon.com>
 // Copyright 2015 Adam Reichold <adam.reichold@t-online.de>
 // Copyright 2015 Jakub Wilk <jwilk@jwilk.net>
+// Copyright 2022 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // Licensed under GPLv2 or later
 //
@@ -39,7 +40,7 @@ struct JPXStreamPrivate
     int ncomps;
     bool inited;
     int smaskInData;
-    void init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int length, bool indexed);
+    void init2(OPJ_CODEC_FORMAT format, const unsigned char *buf, int length, bool indexed);
 };
 
 static inline unsigned char adjustComp(int r, int adjust, int depth, int sgndcorr, bool indexed)
@@ -52,15 +53,17 @@ static inline unsigned char adjustComp(int r, int adjust, int depth, int sgndcor
             r = r << (8 - depth);
         }
     }
-    if (unlikely(r > 255))
+    if (unlikely(r > 255)) {
         r = 255;
+    }
     return r;
 }
 
 static inline int doLookChar(JPXStreamPrivate *priv)
 {
-    if (unlikely(priv->counter >= priv->npixels))
+    if (unlikely(priv->counter >= priv->npixels)) {
         return EOF;
+    }
 
     return ((unsigned char *)priv->image->comps[priv->ccounter].data)[priv->counter];
 }
@@ -119,10 +122,11 @@ int JPXStream::getChars(int nChars, unsigned char *buffer)
 
     for (int i = 0; i < nChars; ++i) {
         const int c = doGetChar(priv);
-        if (likely(c != EOF))
+        if (likely(c != EOF)) {
             buffer[i] = c;
-        else
+        } else {
             return i;
+        }
     }
     return nChars;
 }
@@ -150,7 +154,7 @@ GooString *JPXStream::getPSFilter(int psLevel, const char *indent)
     return nullptr;
 }
 
-bool JPXStream::isBinary(bool last)
+bool JPXStream::isBinary(bool last) const
 {
     return str->isBinary(true);
 }
@@ -174,12 +178,13 @@ void JPXStream::getImageParams(int *bitsPerComponent, StreamColorSpaceMode *csMo
             numComps = 4;
         }
     }
-    if (numComps == 3)
+    if (numComps == 3) {
         *csMode = streamCSDeviceRGB;
-    else if (numComps == 4)
+    } else if (numComps == 4) {
         *csMode = streamCSDeviceCMYK;
-    else
+    } else {
         *csMode = streamCSDeviceGray;
+    }
 }
 
 static void libopenjpeg_error_callback(const char *msg, void * /*client_data*/)
@@ -194,7 +199,7 @@ static void libopenjpeg_warning_callback(const char *msg, void * /*client_data*/
 
 typedef struct JPXData_s
 {
-    unsigned char *data;
+    const unsigned char *data;
     int size;
     int pos;
 } JPXData;
@@ -207,12 +212,15 @@ static OPJ_SIZE_T jpxRead_callback(void *p_buffer, OPJ_SIZE_T p_nb_bytes, void *
     int len;
 
     len = jpxData->size - jpxData->pos;
-    if (len < 0)
+    if (len < 0) {
         len = 0;
-    if (len == 0)
+    }
+    if (len == 0) {
         return (OPJ_SIZE_T)-1; /* End of file! */
-    if ((OPJ_SIZE_T)len > p_nb_bytes)
+    }
+    if ((OPJ_SIZE_T)len > p_nb_bytes) {
         len = p_nb_bytes;
+    }
     memcpy(p_buffer, jpxData->data + jpxData->pos, len);
     jpxData->pos += len;
     return len;
@@ -231,8 +239,9 @@ static OPJ_BOOL jpxSeek_callback(OPJ_OFF_T seek_pos, void *p_user_data)
 {
     JPXData *jpxData = (JPXData *)p_user_data;
 
-    if (seek_pos > jpxData->size)
+    if (seek_pos > jpxData->size) {
         return OPJ_FALSE;
+    }
     jpxData->pos = seek_pos;
     return OPJ_TRUE;
 }
@@ -247,49 +256,49 @@ void JPXStream::init()
     }
 
     int bufSize = BUFFER_INITIAL_SIZE;
-    if (oLen.isInt() && oLen.getInt() > 0)
+    if (oLen.isInt() && oLen.getInt() > 0) {
         bufSize = oLen.getInt();
+    }
 
     bool indexed = false;
     if (cspace.isArray() && cspace.arrayGetLength() > 0) {
         const Object cstype = cspace.arrayGet(0);
-        if (cstype.isName("Indexed"))
+        if (cstype.isName("Indexed")) {
             indexed = true;
+        }
     }
 
     priv->smaskInData = 0;
-    if (smaskInData.isInt())
+    if (smaskInData.isInt()) {
         priv->smaskInData = smaskInData.getInt();
+    }
 
-    int length = 0;
-    unsigned char *buf = str->toUnsignedChars(&length, bufSize);
-    priv->init2(OPJ_CODEC_JP2, buf, length, indexed);
-    gfree(buf);
+    const std::vector<unsigned char> buf = str->toUnsignedChars(bufSize);
+    priv->init2(OPJ_CODEC_JP2, buf.data(), buf.size(), indexed);
 
     if (priv->image) {
-        int numComps = (priv->image) ? priv->image->numcomps : 1;
+        int numComps = priv->image->numcomps;
         int alpha = 0;
-        if (priv->image) {
-            if (priv->image->color_space == OPJ_CLRSPC_SRGB && numComps == 4) {
-                numComps = 3;
-                alpha = 1;
-            } else if (priv->image->color_space == OPJ_CLRSPC_SYCC && numComps == 4) {
-                numComps = 3;
-                alpha = 1;
-            } else if (numComps == 2) {
-                numComps = 1;
-                alpha = 1;
-            } else if (numComps > 4) {
-                numComps = 4;
-                alpha = 1;
-            } else {
-                alpha = 0;
-            }
+        if (priv->image->color_space == OPJ_CLRSPC_SRGB && numComps == 4) {
+            numComps = 3;
+            alpha = 1;
+        } else if (priv->image->color_space == OPJ_CLRSPC_SYCC && numComps == 4) {
+            numComps = 3;
+            alpha = 1;
+        } else if (numComps == 2) {
+            numComps = 1;
+            alpha = 1;
+        } else if (numComps > 4) {
+            numComps = 4;
+            alpha = 1;
+        } else {
+            alpha = 0;
         }
         priv->npixels = priv->image->comps[0].w * priv->image->comps[0].h;
         priv->ncomps = priv->image->numcomps;
-        if (alpha == 1 && priv->smaskInData == 0)
+        if (alpha == 1 && priv->smaskInData == 0) {
             priv->ncomps--;
+        }
         for (int component = 0; component < priv->ncomps; component++) {
             if (priv->image->comps[component].data == nullptr) {
                 close();
@@ -304,11 +313,13 @@ void JPXStream::init()
             unsigned char *cdata = (unsigned char *)priv->image->comps[component].data;
             int adjust = 0;
             int depth = priv->image->comps[component].prec;
-            if (priv->image->comps[component].prec > 8)
+            if (priv->image->comps[component].prec > 8) {
                 adjust = priv->image->comps[component].prec - 8;
+            }
             int sgndcorr = 0;
-            if (priv->image->comps[component].sgnd)
+            if (priv->image->comps[component].sgnd) {
                 sgndcorr = 1 << (priv->image->comps[0].prec - 1);
+            }
             for (int i = 0; i < priv->npixels; i++) {
                 int r = priv->image->comps[component].data[i];
                 *(cdata++) = adjustComp(r, adjust, depth, sgndcorr, indexed);
@@ -323,7 +334,7 @@ void JPXStream::init()
     priv->inited = true;
 }
 
-void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int length, bool indexed)
+void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, const unsigned char *buf, int length, bool indexed)
 {
     JPXData jpxData;
 
@@ -352,8 +363,9 @@ void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int le
     /* Use default decompression parameters */
     opj_dparameters_t parameters;
     opj_set_default_decoder_parameters(&parameters);
-    if (indexed)
+    if (indexed) {
         parameters.flags |= OPJ_DPARAMETERS_IGNORE_PCLR_CMAP_CDEF_FLAG;
+    }
 
     /* Get the decoder handle of the format */
     decoder = opj_create_decompress(format);
@@ -394,8 +406,9 @@ void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int le
     opj_destroy_codec(decoder);
     opj_stream_destroy(stream);
 
-    if (image != nullptr)
+    if (image != nullptr) {
         return;
+    }
 
 error:
     if (image != nullptr) {
