@@ -70,7 +70,9 @@
 #include <cstddef>
 #include <cstring>
 #include <ctime>
+#include <iomanip>
 #include <regex>
+#include <sstream>
 #include <sys/stat.h>
 #include "goo/glibc.h"
 #include "goo/gstrtod.h"
@@ -86,7 +88,6 @@
 #include "Link.h"
 #include "OutputDev.h"
 #include "Error.h"
-#include "ErrorCodes.h"
 #include "Lexer.h"
 #include "Parser.h"
 #include "SecurityHandler.h"
@@ -118,91 +119,57 @@
 // PDFDoc
 //------------------------------------------------------------------------
 
-#define pdfdocLocker() std::unique_lock<std::recursive_mutex> locker(mutex)
+#define pdfdocLocker() const std::scoped_lock locker(mutex)
 
-void PDFDoc::init()
-{
-    ok = false;
-    errCode = errNone;
-    fileName = nullptr;
-    file = nullptr;
-    str = nullptr;
-    xref = nullptr;
-    linearization = nullptr;
-    catalog = nullptr;
-    hints = nullptr;
-    outline = nullptr;
-    startXRefPos = -1;
-    secHdlr = nullptr;
-    pageCache = nullptr;
-}
+PDFDoc::PDFDoc() { }
 
-PDFDoc::PDFDoc()
-{
-    init();
-}
-
-PDFDoc::PDFDoc(const GooString *fileNameA, const GooString *ownerPassword, const GooString *userPassword, void *guiDataA, const std::function<void()> &xrefReconstructedCallback)
+PDFDoc::PDFDoc(std::unique_ptr<GooString> &&fileNameA, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword, void *guiDataA, const std::function<void()> &xrefReconstructedCallback)
+    : fileName(std::move(fileNameA)), guiData(guiDataA)
 {
 #ifdef _WIN32
-    int n, i;
-#endif
-
-    init();
-
-    fileName = fileNameA;
-    guiData = guiDataA;
-#ifdef _WIN32
-    n = fileName->getLength();
+    const int n = fileName->getLength();
     fileNameU = (wchar_t *)gmallocn(n + 1, sizeof(wchar_t));
-    for (i = 0; i < n; ++i) {
+    for (int i = 0; i < n; ++i) {
         fileNameU[i] = (wchar_t)(fileName->getChar(i) & 0xff);
     }
     fileNameU[n] = L'\0';
-#endif
 
-    // try to open file
-#ifdef _WIN32
     wchar_t *wFileName = (wchar_t *)utf8ToUtf16(fileName->c_str());
     file = GooFile::open(wFileName);
     gfree(wFileName);
 #else
     file = GooFile::open(fileName->toStr());
 #endif
-    if (file == nullptr) {
+
+    if (!file) {
         // fopen() has failed.
         // Keep a copy of the errno returned by fopen so that it can be
         // referred to later.
         fopenErrno = errno;
-        error(errIO, -1, "Couldn't open file '{0:t}': {1:s}.", fileName, strerror(errno));
+        error(errIO, -1, "Couldn't open file '{0:t}': {1:s}.", fileName.get(), strerror(errno));
         errCode = errOpenFile;
         return;
     }
 
     // create stream
-    str = new FileStream(file, 0, false, file->size(), Object(objNull));
+    str = new FileStream(file.get(), 0, false, file->size(), Object(objNull));
 
     ok = setup(ownerPassword, userPassword, xrefReconstructedCallback);
 }
 
 #ifdef _WIN32
-PDFDoc::PDFDoc(wchar_t *fileNameA, int fileNameLen, GooString *ownerPassword, GooString *userPassword, void *guiDataA, const std::function<void()> &xrefReconstructedCallback)
+PDFDoc::PDFDoc(wchar_t *fileNameA, int fileNameLen, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword, void *guiDataA, const std::function<void()> &xrefReconstructedCallback) : guiData(guiDataA)
 {
     OSVERSIONINFO version;
-    int i;
-
-    init();
-
-    guiData = guiDataA;
 
     // save both Unicode and 8-bit copies of the file name
     GooString *fileNameG = new GooString();
     fileNameU = (wchar_t *)gmallocn(fileNameLen + 1, sizeof(wchar_t));
-    for (i = 0; i < fileNameLen; ++i) {
+    for (int i = 0; i < fileNameLen; ++i) {
         fileNameG->append((char)fileNameA[i]);
         fileNameU[i] = fileNameA[i];
     }
-    fileName = fileNameG;
+    fileName.reset(fileNameG);
     fileNameU[fileNameLen] = L'\0';
 
     // try to open file
@@ -215,47 +182,36 @@ PDFDoc::PDFDoc(wchar_t *fileNameA, int fileNameLen, GooString *ownerPassword, Go
         file = GooFile::open(fileName->toStr());
     }
     if (!file) {
-        error(errIO, -1, "Couldn't open file '{0:t}'", fileName);
+        error(errIO, -1, "Couldn't open file '{0:t}'", fileName.get());
         errCode = errOpenFile;
         return;
     }
 
     // create stream
-    str = new FileStream(file, 0, false, file->size(), Object(objNull));
+    str = new FileStream(file.get(), 0, false, file->size(), Object(objNull));
 
     ok = setup(ownerPassword, userPassword, xrefReconstructedCallback);
 }
 #endif
 
-PDFDoc::PDFDoc(BaseStream *strA, const GooString *ownerPassword, const GooString *userPassword, void *guiDataA, const std::function<void()> &xrefReconstructedCallback)
+PDFDoc::PDFDoc(BaseStream *strA, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword, void *guiDataA, const std::function<void()> &xrefReconstructedCallback) : guiData(guiDataA)
 {
-#ifdef _WIN32
-    int n, i;
-#endif
-
-    init();
-    guiData = guiDataA;
     if (strA->getFileName()) {
-        fileName = strA->getFileName()->copy();
+        fileName.reset(strA->getFileName()->copy());
 #ifdef _WIN32
-        n = fileName->getLength();
+        const int n = fileName->getLength();
         fileNameU = (wchar_t *)gmallocn(n + 1, sizeof(wchar_t));
-        for (i = 0; i < n; ++i) {
+        for (int i = 0; i < n; ++i) {
             fileNameU[i] = (wchar_t)(fileName->getChar(i) & 0xff);
         }
         fileNameU[n] = L'\0';
-#endif
-    } else {
-        fileName = nullptr;
-#ifdef _WIN32
-        fileNameU = NULL;
 #endif
     }
     str = strA;
     ok = setup(ownerPassword, userPassword, xrefReconstructedCallback);
 }
 
-bool PDFDoc::setup(const GooString *ownerPassword, const GooString *userPassword, const std::function<void()> &xrefReconstructedCallback)
+bool PDFDoc::setup(const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword, const std::function<void()> &xrefReconstructedCallback)
 {
     pdfdocLocker();
 
@@ -340,34 +296,14 @@ PDFDoc::~PDFDoc()
         gfree(pageCache);
     }
     delete secHdlr;
-    if (outline) {
-        delete outline;
-    }
-    if (catalog) {
-        delete catalog;
-    }
-    if (xref) {
-        delete xref;
-    }
-    if (hints) {
-        delete hints;
-    }
-    if (linearization) {
-        delete linearization;
-    }
-    if (str) {
-        delete str;
-    }
-    if (file) {
-        delete file;
-    }
-    if (fileName) {
-        delete fileName;
-    }
+    delete outline;
+    delete catalog;
+    delete xref;
+    delete hints;
+    delete linearization;
+    delete str;
 #ifdef _WIN32
-    if (fileNameU) {
-        gfree(fileNameU);
-    }
+    gfree(fileNameU);
 #endif
 }
 
@@ -381,8 +317,9 @@ bool PDFDoc::checkFooter()
     int i, ch;
     for (i = 0; i < 1024; i++) {
         ch = str->getChar();
-        if (ch == EOF)
+        if (ch == EOF) {
             break;
+        }
         eof[i] = ch;
     }
     eof[i] = '\0';
@@ -421,8 +358,9 @@ void PDFDoc::checkHeader()
     // read up to headerSearchSize bytes from the beginning of the document
     for (i = 0; i < headerSearchSize; ++i) {
         const int c = str->getChar();
-        if (c == EOF)
+        if (c == EOF) {
             break;
+        }
         hdrBuf[i] = c;
     }
     bytesRead = i;
@@ -449,7 +387,7 @@ void PDFDoc::checkHeader()
     // We don't do the version check. Don't add it back in.
 }
 
-bool PDFDoc::checkEncryption(const GooString *ownerPassword, const GooString *userPassword)
+bool PDFDoc::checkEncryption(const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword)
 {
     bool encrypted;
     bool ret;
@@ -620,53 +558,43 @@ static void addSignatureFieldsToVector(FormField *ff, std::vector<FormFieldSigna
 
 std::vector<FormFieldSignature *> PDFDoc::getSignatureFields()
 {
+    // Unfortunately there's files with signatures in Forms but not in Annots
+    // and files with signatures in Annots but no in forms so we need to search both
     std::vector<FormFieldSignature *> res;
 
+    // First search
     const Form *f = catalog->getForm();
-    if (!f)
+    if (!f) {
         return res;
+    }
 
     const int nRootFields = f->getNumFields();
     for (int i = 0; i < nRootFields; ++i) {
         FormField *ff = f->getRootField(i);
         addSignatureFieldsToVector(ff, res);
     }
+
+    // Second search
+    for (int page = 1; page <= getNumPages(); ++page) {
+        Page *p = getPage(page);
+        if (p) {
+            const std::unique_ptr<FormPageWidgets> pw = p->getFormWidgets();
+            for (int i = 0; i < pw->getNumWidgets(); ++i) {
+                FormWidget *fw = pw->getWidget(i);
+                if (fw->getType() == formSignature) {
+                    assert(fw->getField()->getType() == formSignature);
+                    FormFieldSignature *ffs = static_cast<FormFieldSignature *>(fw->getField());
+                    if (std::find(res.begin(), res.end(), ffs) == res.end()) {
+                        res.push_back(ffs);
+                    }
+                }
+            }
+        }
+    }
+
     return res;
 }
 
-static int sumSignatureFields(FormField *ff)
-{
-    int sum = 0;
-
-    if (ff->getNumChildren() == 0) {
-        if (ff->getType() == formSignature) {
-            sum = 1;
-        }
-    } else {
-        for (int i = 0; i < ff->getNumChildren(); ++i) {
-            FormField *children = ff->getChildren(i);
-            sum += sumSignatureFields(children);
-        }
-    }
-    return sum;
-}
-
-int PDFDoc::getNumSignatureFields()
-{
-    const Form *f = catalog->getForm();
-
-    if (!f)
-        return 0;
-
-    const int nRootFields = f->getNumFields();
-    int sum = 0;
-    for (int i = 0; i < nRootFields; ++i) {
-        FormField *ff = f->getRootField(i);
-        sum += sumSignatureFields(ff);
-    }
-    return sum;
-}
-
 void PDFDoc::displayPage(OutputDev *out, int page, double hDPI, double vDPI, int rotate, bool useMediaBox, bool crop, bool printing, bool (*abortCheckCbk)(void *data), void *abortCheckCbkData,
                          bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data), void *annotDisplayDecideCbkData, bool copyXRef)
 {
@@ -674,8 +602,9 @@ void PDFDoc::displayPage(OutputDev *out, int page, double hDPI, double vDPI, int
         printf("***** page %d *****\n", page);
     }
 
-    if (getPage(page))
+    if (getPage(page)) {
         getPage(page)->display(out, hDPI, vDPI, rotate, useMediaBox, crop, printing, abortCheckCbk, abortCheckCbkData, annotDisplayDecideCbk, annotDisplayDecideCbkData, copyXRef);
+    }
 }
 
 void PDFDoc::displayPages(OutputDev *out, int firstPage, int lastPage, double hDPI, double vDPI, int rotate, bool useMediaBox, bool crop, bool printing, bool (*abortCheckCbk)(void *data), void *abortCheckCbkData,
@@ -691,8 +620,9 @@ void PDFDoc::displayPages(OutputDev *out, int firstPage, int lastPage, double hD
 void PDFDoc::displayPageSlice(OutputDev *out, int page, double hDPI, double vDPI, int rotate, bool useMediaBox, bool crop, bool printing, int sliceX, int sliceY, int sliceW, int sliceH, bool (*abortCheckCbk)(void *data),
                               void *abortCheckCbkData, bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data), void *annotDisplayDecideCbkData, bool copyXRef)
 {
-    if (getPage(page))
+    if (getPage(page)) {
         getPage(page)->displaySlice(out, hDPI, vDPI, rotate, useMediaBox, crop, sliceX, sliceY, sliceW, sliceH, printing, abortCheckCbk, abortCheckCbkData, annotDisplayDecideCbk, annotDisplayDecideCbkData, copyXRef);
+    }
 }
 
 std::unique_ptr<Links> PDFDoc::getLinks(int page)
@@ -706,8 +636,9 @@ std::unique_ptr<Links> PDFDoc::getLinks(int page)
 
 void PDFDoc::processLinks(OutputDev *out, int page)
 {
-    if (getPage(page))
+    if (getPage(page)) {
         getPage(page)->processLinks(out);
+    }
 }
 
 Linearization *PDFDoc::getLinearization()
@@ -721,12 +652,15 @@ Linearization *PDFDoc::getLinearization()
 
 bool PDFDoc::checkLinearization()
 {
-    if (linearization == nullptr)
+    if (linearization == nullptr) {
         return false;
-    if (linearizationState == 1)
+    }
+    if (linearizationState == 1) {
         return true;
-    if (linearizationState == 2)
+    }
+    if (linearizationState == 2) {
         return false;
+    }
     if (!hints) {
         hints = new Hints(str, linearization, getXRef(), secHdlr);
     }
@@ -762,13 +696,14 @@ bool PDFDoc::checkLinearization()
 
 bool PDFDoc::isLinearized(bool tryingToReconstruct)
 {
-    if ((str->getLength()) && (getLinearization()->getLength() == str->getLength()))
+    if ((str->getLength()) && (getLinearization()->getLength() == str->getLength())) {
         return true;
-    else {
-        if (tryingToReconstruct)
+    } else {
+        if (tryingToReconstruct) {
             return getLinearization()->getLength() > 0;
-        else
+        } else {
             return false;
+        }
     }
 }
 
@@ -822,13 +757,15 @@ static bool get_id(const GooString *encodedidstring, GooString *id)
     char pdfid[pdfIdLength + 1];
     int n;
 
-    if (encodedidstring->getLength() != pdfIdLength / 2)
+    if (encodedidstring->getLength() != pdfIdLength / 2) {
         return false;
+    }
 
     n = sprintf(pdfid, "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x", encodedid[0] & 0xff, encodedid[1] & 0xff, encodedid[2] & 0xff, encodedid[3] & 0xff, encodedid[4] & 0xff, encodedid[5] & 0xff, encodedid[6] & 0xff,
                 encodedid[7] & 0xff, encodedid[8] & 0xff, encodedid[9] & 0xff, encodedid[10] & 0xff, encodedid[11] & 0xff, encodedid[12] & 0xff, encodedid[13] & 0xff, encodedid[14] & 0xff, encodedid[15] & 0xff);
-    if (n != pdfIdLength)
+    if (n != pdfIdLength) {
         return false;
+    }
 
     id->Set(pdfid, pdfIdLength);
     return true;
@@ -878,14 +815,15 @@ Hints *PDFDoc::getHints()
     return hints;
 }
 
-int PDFDoc::savePageAs(const GooString *name, int pageNo)
+int PDFDoc::savePageAs(const GooString &name, int pageNo)
 {
     FILE *f;
     OutStream *outStr;
     XRef *yRef, *countRef;
 
-    if (file && file->modificationTimeChangedSinceOpen())
+    if (file && file->modificationTimeChangedSinceOpen()) {
         return errFileChangedSinceOpen;
+    }
 
     int rootNum = getXRef()->getNumObjects() + 1;
 
@@ -910,8 +848,8 @@ int PDFDoc::savePageAs(const GooString *name, int pageNo)
     Ref *refPage = getCatalog()->getPageRef(pageNo);
     Object page = getXRef()->fetch(*refPage);
 
-    if (!(f = openFile(name->c_str(), "wb"))) {
-        error(errIO, -1, "Couldn't open file '{0:t}'", name);
+    if (!(f = openFile(name.c_str(), "wb"))) {
+        error(errIO, -1, "Couldn't open file '{0:t}'", &name);
         return errOpenFile;
     }
     outStr = new FileOutStream(f, 0);
@@ -956,8 +894,9 @@ int PDFDoc::savePageAs(const GooString *name, int pageNo)
     }
     Dict *pagesDict = pagesObj.getDict();
     Object resourcesObj = pagesDict->lookup("Resources");
-    if (resourcesObj.isDict())
+    if (resourcesObj.isDict()) {
         markPageObjects(resourcesObj.getDict(), yRef, countRef, 0, refPage->num, rootNum + 2);
+    }
     markPageObjects(catDict, yRef, countRef, 0, refPage->num, rootNum + 2);
 
     Dict *pageDict = page.getDict();
@@ -982,8 +921,9 @@ int PDFDoc::savePageAs(const GooString *name, int pageNo)
     for (int j = 0; j < catDict->getLength(); j++) {
         const char *key = catDict->getKey(j);
         if (strcmp(key, "Type") != 0 && strcmp(key, "Catalog") != 0 && strcmp(key, "Pages") != 0) {
-            if (j > 0)
+            if (j > 0) {
                 outStr->printf(" ");
+            }
             Object value = catDict->getValNF(j).copy();
             outStr->printf("/%s ", key);
             writeObject(&value, outStr, getXRef(), 0, nullptr, cryptRC4, 0, 0, 0);
@@ -1005,8 +945,9 @@ int PDFDoc::savePageAs(const GooString *name, int pageNo)
     outStr->printf("%d 0 obj\n", rootNum + 2);
     outStr->printf("<< ");
     for (int n = 0; n < pageDict->getLength(); n++) {
-        if (n > 0)
+        if (n > 0) {
             outStr->printf(" ");
+        }
         const char *key = pageDict->getKey(n);
         Object value = pageDict->getValNF(n).copy();
         if (strcmp(key, "Parent") == 0) {
@@ -1022,7 +963,7 @@ int PDFDoc::savePageAs(const GooString *name, int pageNo)
     Ref ref;
     ref.num = rootNum;
     ref.gen = 0;
-    Object trailerDict = createTrailerDict(rootNum + 3, false, 0, &ref, getXRef(), name->c_str(), uxrefOffset);
+    Object trailerDict = createTrailerDict(rootNum + 3, false, 0, &ref, getXRef(), name.c_str(), uxrefOffset);
     writeXRefTableTrailer(std::move(trailerDict), yRef, false /* do not write unnecessary entries */, uxrefOffset, outStr, getXRef());
 
     outStr->close();
@@ -1034,14 +975,14 @@ int PDFDoc::savePageAs(const GooString *name, int pageNo)
     return errNone;
 }
 
-int PDFDoc::saveAs(const GooString *name, PDFWriteMode mode)
+int PDFDoc::saveAs(const GooString &name, PDFWriteMode mode)
 {
     FILE *f;
     OutStream *outStr;
     int res;
 
-    if (!(f = openFile(name->c_str(), "wb"))) {
-        error(errIO, -1, "Couldn't open file '{0:t}'", name);
+    if (!(f = openFile(name.c_str(), "wb"))) {
+        error(errIO, -1, "Couldn't open file '{0:t}'", &name);
         return errOpenFile;
     }
     outStr = new FileOutStream(f, 0);
@@ -1053,8 +994,9 @@ int PDFDoc::saveAs(const GooString *name, PDFWriteMode mode)
 
 int PDFDoc::saveAs(OutStream *outStr, PDFWriteMode mode)
 {
-    if (file && file->modificationTimeChangedSinceOpen())
+    if (file && file->modificationTimeChangedSinceOpen()) {
         return errFileChangedSinceOpen;
+    }
 
     if (!xref->isModified() && mode == writeStandard) {
         // simply copy the original file
@@ -1068,14 +1010,14 @@ int PDFDoc::saveAs(OutStream *outStr, PDFWriteMode mode)
     return errNone;
 }
 
-int PDFDoc::saveWithoutChangesAs(const GooString *name)
+int PDFDoc::saveWithoutChangesAs(const GooString &name)
 {
     FILE *f;
     OutStream *outStr;
     int res;
 
-    if (!(f = openFile(name->c_str(), "wb"))) {
-        error(errIO, -1, "Couldn't open file '{0:t}'", name);
+    if (!(f = openFile(name.c_str(), "wb"))) {
+        error(errIO, -1, "Couldn't open file '{0:t}'", &name);
         return errOpenFile;
     }
 
@@ -1092,8 +1034,9 @@ int PDFDoc::saveWithoutChangesAs(OutStream *outStr)
 {
     int c;
 
-    if (file && file->modificationTimeChangedSinceOpen())
+    if (file && file->modificationTimeChangedSinceOpen()) {
         return errFileChangedSinceOpen;
+    }
 
     BaseStream *copyStr = str->copy();
     copyStr->reset();
@@ -1128,8 +1071,9 @@ void PDFDoc::saveIncrementalUpdate(OutStream *outStr)
     uxref->add(0, 65535, 0, false);
     xref->lock();
     for (int i = 0; i < xref->getNumObjects(); i++) {
-        if ((xref->getEntry(i)->type == xrefEntryFree) && (xref->getEntry(i)->gen == 0)) // we skip the irrelevant free objects
+        if ((xref->getEntry(i)->type == xrefEntryFree) && (xref->getEntry(i)->gen == 0)) { // we skip the irrelevant free objects
             continue;
+        }
 
         if (xref->getEntry(i)->getFlag(XRefEntry::Updated)) { // we have an updated object
             Ref ref;
@@ -1204,8 +1148,9 @@ void PDFDoc::saveCompleteRewrite(OutStream *outStr)
             ref.gen = xref->getEntry(i)->gen;
             /* the XRef class adds a lot of irrelevant free entries, we only want the significant one
                 and we don't want the one with num=0 because it has already been added (gen = 65535)*/
-            if (ref.gen > 0 && ref.num > 0)
+            if (ref.gen > 0 && ref.num > 0) {
                 uxref->add(ref, 0, false);
+            }
         } else if (xref->getEntry(i)->getFlag(XRefEntry::DontRewrite)) {
             // This entry must not be written, put a free entry instead (with incremented gen)
             ref.num = i;
@@ -1250,8 +1195,9 @@ void PDFDoc::writeDictionnary(Dict *dict, OutStream *outStr, XRef *xRef, unsigne
 
     if (alreadyWrittenDicts->find(dict) != alreadyWrittenDicts->end()) {
         error(errSyntaxWarning, -1, "PDFDoc::writeDictionnary: Found recursive dicts");
-        if (deleteSet)
+        if (deleteSet) {
             delete alreadyWrittenDicts;
+        }
         return;
     } else {
         alreadyWrittenDicts->insert(dict);
@@ -1292,10 +1238,11 @@ void PDFDoc::writeRawStream(Stream *str, OutStream *outStr)
     }
 
     Goffset length;
-    if (obj1.isInt())
+    if (obj1.isInt()) {
         length = obj1.getInt();
-    else
+    } else {
         length = obj1.getInt64();
+    }
 
     outStr->printf("stream\r\n");
     str->unfilteredReset();
@@ -1332,26 +1279,25 @@ void PDFDoc::writeString(const GooString *s, OutStream *outStr, const unsigned c
     if (s->hasUnicodeMarker()) {
         // unicode string don't necessary end with \0
         const char *c = s->c_str();
-        outStr->printf("(");
+        std::stringstream stream;
+        stream << std::setfill('0') << std::hex;
         for (int i = 0; i < s->getLength(); i++) {
-            char unescaped = *(c + i) & 0x000000ff;
-            // escape if needed
-            if (unescaped == '(' || unescaped == ')' || unescaped == '\\')
-                outStr->printf("%c", '\\');
-            outStr->printf("%c", unescaped);
+            stream << std::setw(2) << (0xff & (unsigned int)*(c + i));
         }
-        outStr->printf(") ");
+        outStr->printf("<");
+        outStr->printf("%s", stream.str().c_str());
+        outStr->printf("> ");
     } else {
         const char *c = s->c_str();
         outStr->printf("(");
         for (int i = 0; i < s->getLength(); i++) {
             char unescaped = *(c + i) & 0x000000ff;
             // escape if needed
-            if (unescaped == '\r')
+            if (unescaped == '\r') {
                 outStr->printf("\\r");
-            else if (unescaped == '\n')
+            } else if (unescaped == '\n') {
                 outStr->printf("\\n");
-            else {
+            } else {
                 if (unescaped == '(' || unescaped == ')' || unescaped == '\\') {
                     outStr->printf("%c", '\\');
                 }
@@ -1556,8 +1502,9 @@ Object PDFDoc::createTrailerDict(int uxrefSize, bool incrUpdate, Goffset startxR
     sprintf(buffer, "%i", (int)time(nullptr));
     message.append(buffer);
 
-    if (fileName)
+    if (fileName) {
         message.append(fileName);
+    }
 
     sprintf(buffer, "%lli", (long long)fileSize);
     message.append(buffer);
@@ -1594,7 +1541,9 @@ Object PDFDoc::createTrailerDict(int uxrefSize, bool incrUpdate, Goffset startxR
         // only update the second part of the array
         Object obj4 = xRef->getTrailerDict()->getDict()->lookup("ID");
         if (!obj4.isArray()) {
-            error(errSyntaxWarning, -1, "PDFDoc::createTrailerDict original file's ID entry isn't an array. Trying to continue");
+            if (hasEncrypt) {
+                error(errSyntaxWarning, -1, "PDFDoc::createTrailerDict original file's ID entry isn't an array. Trying to continue");
+            }
         } else {
             Array *array = new Array(xRef);
             // Get the first part of the ID
@@ -1689,8 +1638,9 @@ void PDFDoc::markDictionnary(Dict *dict, XRef *xRef, XRef *countRef, unsigned in
 
     if (alreadyMarkedDicts->find(dict) != alreadyMarkedDicts->end()) {
         error(errSyntaxWarning, -1, "PDFDoc::markDictionnary: Found recursive dicts");
-        if (deleteSet)
+        if (deleteSet) {
             delete alreadyMarkedDicts;
+        }
         return;
     } else {
         alreadyMarkedDicts->insert(dict);
@@ -1748,8 +1698,9 @@ void PDFDoc::markObject(Object *obj, XRef *xRef, XRef *countRef, unsigned int nu
         } else {
             XRefEntry *entry = countRef->getEntry(obj->getRef().num + numOffset);
             entry->gen++;
-            if (entry->gen > 9)
+            if (entry->gen > 9) {
                 break;
+            }
         }
         Object obj1 = getXRef()->fetch(obj->getRef());
         markObject(&obj1, xRef, countRef, numOffset, oldRefNum, newRefNum);
@@ -1972,12 +1923,12 @@ Outline *PDFDoc::getOutline()
     return outline;
 }
 
-std::unique_ptr<PDFDoc> PDFDoc::ErrorPDFDoc(int errorCode, const GooString *fileNameA)
+std::unique_ptr<PDFDoc> PDFDoc::ErrorPDFDoc(int errorCode, std::unique_ptr<GooString> &&fileNameA)
 {
     // We cannot call std::make_unique here because the PDFDoc constructor is private
     PDFDoc *doc = new PDFDoc();
     doc->errCode = errorCode;
-    doc->fileName = fileNameA;
+    doc->fileName = std::move(fileNameA);
 
     return std::unique_ptr<PDFDoc>(doc);
 }
@@ -2022,8 +1973,9 @@ Goffset PDFDoc::getStartXRef(bool tryingToReconstruct)
                 if (!strncmp("endobj", &buf[i], 6)) {
                     i += 6;
                     // skip whitespace
-                    while (buf[i] && Lexer::isSpace(buf[i]))
+                    while (buf[i] && Lexer::isSpace(buf[i])) {
                         ++i;
+                    }
                     startXRefPos = i;
                     break;
                 }
@@ -2036,8 +1988,9 @@ Goffset PDFDoc::getStartXRef(bool tryingToReconstruct)
             // read last xrefSearchSize bytes
             int segnum = 0;
             int maxXRefSearch = 24576;
-            if (str->getLength() < maxXRefSearch)
+            if (str->getLength() < maxXRefSearch) {
                 maxXRefSearch = str->getLength();
+            }
             for (; (xrefSearchSize - 16) * segnum < maxXRefSearch; segnum++) {
                 str->setPos((xrefSearchSize - 16) * segnum + xrefSearchSize, -1);
                 for (n = 0; n < xrefSearchSize; ++n) {
@@ -2057,8 +2010,9 @@ Goffset PDFDoc::getStartXRef(bool tryingToReconstruct)
                 if (i < 0) {
                     startXRefPos = 0;
                 } else {
-                    for (p = &buf[i + 9]; isspace(*p); ++p)
+                    for (p = &buf[i + 9]; isspace(*p); ++p) {
                         ;
+                    }
                     startXRefPos = strToLongLong(p);
                     break;
                 }
@@ -2121,8 +2075,9 @@ Page *PDFDoc::parsePage(int page)
 
 Page *PDFDoc::getPage(int page)
 {
-    if ((page < 1) || page > getNumPages())
+    if ((page < 1) || page > getNumPages()) {
         return nullptr;
+    }
 
     if (isLinearized() && checkLinearization()) {
         pdfdocLocker();
@@ -2154,7 +2109,7 @@ bool PDFDoc::hasJavascript()
 
 bool PDFDoc::sign(const char *saveFilename, const char *certNickname, const char *password, GooString *partialFieldName, int page, const PDFRectangle &rect, const GooString &signatureText, const GooString &signatureTextLeft,
                   double fontSize, double leftFontSize, std::unique_ptr<AnnotColor> &&fontColor, double borderWidth, std::unique_ptr<AnnotColor> &&borderColor, std::unique_ptr<AnnotColor> &&backgroundColor, const GooString *reason,
-                  const GooString *location, const std::string &imagePath, const GooString *ownerPassword, const GooString *userPassword)
+                  const GooString *location, const std::string &imagePath, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword)
 {
     ::Page *destPage = getPage(page);
     if (destPage == nullptr) {
