@@ -141,10 +141,11 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA, int recursion)
     if (!obj1.isInt() && !obj1.isInt64()) {
         return;
     }
-    if (obj1.isInt())
+    if (obj1.isInt()) {
         first = obj1.getInt();
-    else
+    } else {
         first = obj1.getInt64();
+    }
     if (first < 0) {
         return;
     }
@@ -173,18 +174,20 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA, int recursion)
             return;
         }
         objNums[i] = obj1.getInt();
-        if (obj2.isInt())
+        if (obj2.isInt()) {
             offsets[i] = obj2.getInt();
-        else
+        } else {
             offsets[i] = obj2.getInt64();
+        }
         if (objNums[i] < 0 || offsets[i] < 0 || (i > 0 && offsets[i] < offsets[i - 1])) {
             delete parser;
             gfree(offsets);
             return;
         }
     }
-    while (str->getChar() != EOF)
+    while (str->getChar() != EOF) {
         ;
+    }
     delete parser;
 
     // skip to the first object - this shouldn't be necessary because
@@ -203,8 +206,9 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA, int recursion)
         }
         parser = new Parser(xref, str, false);
         objs[i] = parser->getObj();
-        while (str->getChar() != EOF)
+        while (str->getChar() != EOF) {
             ;
+        }
         delete parser;
     }
 
@@ -256,8 +260,9 @@ XRef::XRef() : objStrs { 5 }
 
 XRef::XRef(const Object *trailerDictA) : XRef {}
 {
-    if (trailerDictA->isDict())
+    if (trailerDictA->isDict()) {
         trailerDict = trailerDictA->copy();
+    }
 }
 
 XRef::XRef(BaseStream *strA, Goffset pos, Goffset mainXRefEntriesOffsetA, bool *wasReconstructed, bool reconstruct, const std::function<void()> &xrefReconstructedCallback) : XRef {}
@@ -412,8 +417,9 @@ int XRef::reserve(int newSize)
     if (newSize > capacity) {
 
         int realNewSize;
-        for (realNewSize = capacity ? 2 * capacity : 1024; newSize > realNewSize && realNewSize > 0; realNewSize <<= 1)
+        for (realNewSize = capacity ? 2 * capacity : 1024; newSize > realNewSize && realNewSize > 0; realNewSize <<= 1) {
             ;
+        }
         if ((realNewSize < 0) || (realNewSize >= INT_MAX / (int)sizeof(XRefEntry))) {
             return 0;
         }
@@ -434,8 +440,9 @@ int XRef::resize(int newSize)
 {
     if (newSize > size) {
 
-        if (reserve(newSize) < newSize)
+        if (reserve(newSize) < newSize) {
             return size;
+        }
 
         for (int i = size; i < newSize; ++i) {
             entries[i].offset = -1;
@@ -613,10 +620,11 @@ bool XRef::readXRefTable(Parser *parser, Goffset *pos, std::vector<Goffset> *fol
     // get the 'Prev' pointer
     obj2 = obj.getDict()->lookupNF("Prev").copy();
     if (obj2.isInt() || obj2.isInt64()) {
-        if (obj2.isInt())
+        if (obj2.isInt()) {
             pos2 = obj2.getInt();
-        else
+        } else {
             pos2 = obj2.getInt64();
+        }
         if (pos2 != *pos) {
             *pos = pos2;
             more = true;
@@ -647,10 +655,11 @@ bool XRef::readXRefTable(Parser *parser, Goffset *pos, std::vector<Goffset> *fol
     // check for an 'XRefStm' key
     obj2 = obj.getDict()->lookup("XRefStm");
     if (obj2.isInt() || obj2.isInt64()) {
-        if (obj2.isInt())
+        if (obj2.isInt()) {
             pos2 = obj2.getInt();
-        else
+        } else {
             pos2 = obj2.getInt64();
+        }
         for (size_t i = 0; ok == true && i < followedXRefStm->size(); ++i) {
             if (followedXRefStm->at(i) == pos2) {
                 ok = false;
@@ -888,8 +897,9 @@ bool XRef::constructXRef(bool *wasReconstructed, bool needCatalogDict)
         p = buf;
 
         // skip whitespace
-        while (*p && Lexer::isSpace(*p & 0xff))
+        while (*p && Lexer::isSpace(*p & 0xff)) {
             ++p;
+        }
 
         oneCycle = true;
         offset = 0;
@@ -933,8 +943,9 @@ bool XRef::constructXRef(bool *wasReconstructed, bool needCatalogDict)
                         } else {
                             ++p;
                         }
-                        while (*p && isspace(*p & 0xff))
+                        while (*p && isspace(*p & 0xff)) {
                             ++p;
+                        }
                         if (isdigit(*p & 0xff)) {
                             gen = atoi(p);
                             do {
@@ -948,8 +959,9 @@ bool XRef::constructXRef(bool *wasReconstructed, bool needCatalogDict)
                                 } else {
                                     ++p;
                                 }
-                                while (*p && isspace(*p & 0xff))
+                                while (*p && isspace(*p & 0xff)) {
                                     ++p;
+                                }
                                 if (!strncmp(p, "obj", 3)) {
                                     if (num >= size) {
                                         if (unlikely(num >= INT_MAX - 1 - 255)) {
@@ -1007,8 +1019,9 @@ bool XRef::constructXRef(bool *wasReconstructed, bool needCatalogDict)
         }
     }
 
-    if (gotRoot)
+    if (gotRoot) {
         return true;
+    }
 
     error(errSyntaxError, -1, "Couldn't find trailer dictionary");
     return false;
@@ -1352,8 +1365,9 @@ int XRef::getNumEntry(Goffset offset)
             }
         }
         return res;
-    } else
+    } else {
         return -1;
+    }
 }
 
 void XRef::add(Ref ref, Goffset offs, bool used)
@@ -1488,8 +1502,9 @@ void XRef::writeXRef(XRef::XRefWriter *writer, bool writeAllEntries)
         writer->startSection(0, size);
         for (int i = 0; i < size; i++) {
             XRefEntry *e = getEntry(i);
-            if (e->gen > 65535)
+            if (e->gen > 65535) {
                 e->gen = 65535; // cap generation number to 65535 (required by PDFReference)
+            }
             writer->writeEntry(e->offset, e->gen, e->type);
         }
     } else {
@@ -1497,20 +1512,23 @@ void XRef::writeXRef(XRef::XRefWriter *writer, bool writeAllEntries)
         while (i < size) {
             int j;
             for (j = i; j < size; j++) { // look for consecutive entries
-                if ((getEntry(j)->type == xrefEntryFree) && (getEntry(j)->gen == 0))
+                if ((getEntry(j)->type == xrefEntryFree) && (getEntry(j)->gen == 0)) {
                     break;
+                }
             }
             if (j - i != 0) {
                 writer->startSection(i, j - i);
                 for (int k = i; k < j; k++) {
                     XRefEntry *e = getEntry(k);
-                    if (e->gen > 65535)
+                    if (e->gen > 65535) {
                         e->gen = 65535; // cap generation number to 65535 (required by PDFReference)
+                    }
                     writer->writeEntry(e->offset, e->gen, e->type);
                 }
                 i = j;
-            } else
+            } else {
                 ++i;
+            }
         }
     }
 }
@@ -1573,8 +1591,9 @@ void XRef::XRefPreScanWriter::startSection(int first, int count) { }
 
 void XRef::XRefPreScanWriter::writeEntry(Goffset offset, int gen, XRefEntryType type)
 {
-    if (offset >= 0x100000000ll)
+    if (offset >= 0x100000000ll) {
         hasOffsetsBeyond4GB = true;
+    }
 }
 
 void XRef::writeStreamToBuffer(GooString *stmBuf, Dict *xrefDict, XRef *xref)
@@ -1604,17 +1623,19 @@ bool XRef::parseEntry(Goffset offset, XRefEntry *entry)
 {
     bool r;
 
-    if (unlikely(entry == nullptr))
+    if (unlikely(entry == nullptr)) {
         return false;
+    }
 
     Parser parser(nullptr, str->makeSubStream(offset, false, 20, Object(objNull)), true);
 
     Object obj1, obj2, obj3;
     if (((obj1 = parser.getObj(), obj1.isInt()) || obj1.isInt64()) && (obj2 = parser.getObj(), obj2.isInt()) && (obj3 = parser.getObj(), obj3.isCmd("n") || obj3.isCmd("f"))) {
-        if (obj1.isInt64())
+        if (obj1.isInt64()) {
             entry->offset = obj1.getInt64();
-        else
+        } else {
             entry->offset = obj1.getInt();
+        }
         entry->gen = obj2.getInt();
         entry->type = obj3.isCmd("n") ? xrefEntryUncompressed : xrefEntryFree;
         entry->obj.setToNull();
@@ -1676,10 +1697,11 @@ struct DummyXRefEntry : XRefEntry
 {
     DummyXRefEntry()
     {
-        offset = 0;
-        gen = -1;
+        offset = -1;
+        gen = 0;
         type = xrefEntryNone;
         flags = 0;
+        obj = Object(objNull);
     }
 };
 
@@ -1760,8 +1782,9 @@ void XRef::markUnencrypted(Object *obj)
     case objRef: {
         const Ref ref = obj->getRef();
         XRefEntry *e = getEntry(ref.num);
-        if (e->getFlag(XRefEntry::Unencrypted))
+        if (e->getFlag(XRefEntry::Unencrypted)) {
             return; // We've already been here: prevent infinite recursion
+        }
         e->setFlag(XRefEntry::Unencrypted, true);
         obj1 = fetch(ref);
         markUnencrypted(&obj1);
