@@ -88,9 +88,8 @@ void TestOptionalContent::checkNoOptionalContent()
 
 void TestOptionalContent::checkIsVisible()
 {
-    GooString *fileName = new GooString(TESTDATADIR "/unittestcases/vis_policy_test.pdf");
     globalParams = std::make_unique<GlobalParams>();
-    PDFDoc *doc = new PDFDoc(fileName);
+    PDFDoc *doc = new PDFDoc(std::make_unique<GooString>(TESTDATADIR "/unittestcases/vis_policy_test.pdf"));
     QVERIFY(doc);
 
     OCGs *ocgs = doc->getOptContentConfig();
@@ -162,8 +161,7 @@ void TestOptionalContent::checkIsVisible()
 void TestOptionalContent::checkVisibilitySetting()
 {
     globalParams = std::make_unique<GlobalParams>();
-    GooString *fileName = new GooString(TESTDATADIR "/unittestcases/vis_policy_test.pdf");
-    PDFDoc *doc = new PDFDoc(fileName);
+    PDFDoc *doc = new PDFDoc(std::make_unique<GooString>(TESTDATADIR "/unittestcases/vis_policy_test.pdf"));
     QVERIFY(doc);
 
     OCGs *ocgs = doc->getOptContentConfig();
