@@ -18,7 +18,7 @@
 // Copyright (C) 2009 Michael K. Johnson <a1237@danlj.org>
 // Copyright (C) 2009 Shen Liang <shenzhuxi@gmail.com>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
-// Copyright (C) 2009, 2010, 2017-2020 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2010, 2017-2020, 2022 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010, 2011-2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2010, 2014 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2010 Jonathan Liu <net147@gmail.com>
@@ -342,14 +342,15 @@ static void writePageImage(GooString *filename)
 
     if (png) {
 #ifdef ENABLE_LIBPNG
-        if (transp)
+        if (transp) {
             writer = new PNGWriter(PNGWriter::RGBA);
-        else if (gray)
+        } else if (gray) {
             writer = new PNGWriter(PNGWriter::GRAY);
-        else if (mono)
+        } else if (mono) {
             writer = new PNGWriter(PNGWriter::MONOCHROME);
-        else
+        } else {
             writer = new PNGWriter(PNGWriter::RGB);
+        }
 
 #    ifdef USE_CMS
         if (icc_data) {
@@ -366,39 +367,44 @@ static void writePageImage(GooString *filename)
 
     } else if (jpeg) {
 #ifdef ENABLE_LIBJPEG
-        if (gray)
+        if (gray) {
             writer = new JpegWriter(JpegWriter::GRAY);
-        else
+        } else {
             writer = new JpegWriter(JpegWriter::RGB);
+        }
 
         static_cast<JpegWriter *>(writer)->setOptimize(jpegOptimize);
         static_cast<JpegWriter *>(writer)->setProgressive(jpegProgressive);
-        if (jpegQuality >= 0)
+        if (jpegQuality >= 0) {
             static_cast<JpegWriter *>(writer)->setQuality(jpegQuality);
+        }
 #endif
     } else if (tiff) {
 #ifdef ENABLE_LIBTIFF
-        if (transp)
+        if (transp) {
             writer = new TiffWriter(TiffWriter::RGBA_PREMULTIPLIED);
-        else if (gray)
+        } else if (gray) {
             writer = new TiffWriter(TiffWriter::GRAY);
-        else if (mono)
+        } else if (mono) {
             writer = new TiffWriter(TiffWriter::MONOCHROME);
-        else
+        } else {
             writer = new TiffWriter(TiffWriter::RGB);
+        }
         static_cast<TiffWriter *>(writer)->setCompressionString(tiffCompressionStr);
 #endif
     }
-    if (!writer)
+    if (!writer) {
         return;
+    }
 
     if (filename->cmp("fd://0") == 0) {
 #if defined(_WIN32) || defined(__CYGWIN__)
         _setmode(fileno(stdout), O_BINARY);
 #endif
         file = stdout;
-    } else
+    } else {
         file = fopen(filename->c_str(), "wb");
+    }
 
     if (!file) {
         fprintf(stderr, "Error opening output file %s\n", filename->c_str());
@@ -454,10 +460,12 @@ static void writePageImage(GooString *filename)
                 // an arbitrary integer approximation of .3*r + .59*g + .11*b
                 const int grayValue = (r * 19661 + g * 38666 + b * 7209 + 32829) >> 16;
                 if (mono) {
-                    if (bit == 7)
+                    if (bit == 7) {
                         *rowp = 0;
-                    if (grayValue > 127)
+                    }
+                    if (grayValue > 127) {
                         *rowp |= (1 << bit);
+                    }
                     bit--;
                     if (bit < 0) {
                         bit = 7;
@@ -478,10 +486,11 @@ static void writePageImage(GooString *filename)
     gfree(row);
     writer->close();
     delete writer;
-    if (file == stdout)
+    if (file == stdout) {
         fflush(file);
-    else
+    } else {
         fclose(file);
+    }
 }
 
 static void getCropSize(double page_w, double page_h, double *width, double *height)
@@ -489,11 +498,13 @@ static void getCropSize(double page_w, double page_h, double *width, double *hei
     int w = crop_w;
     int h = crop_h;
 
-    if (w == 0)
+    if (w == 0) {
         w = (int)ceil(page_w);
+    }
 
-    if (h == 0)
+    if (h == 0) {
         h = (int)ceil(page_h);
+    }
 
     *width = (crop_x + w > page_w ? (int)ceil(page_w - crop_x) : w);
     *height = (crop_y + h > page_h ? (int)ceil(page_h - crop_y) : h);
@@ -526,15 +537,18 @@ static void getFitToPageTransform(double page_w, double page_h, double paper_w,
 
     x_scale = paper_w / page_w;
     y_scale = paper_h / page_h;
-    if (x_scale < y_scale)
+    if (x_scale < y_scale) {
         scale = x_scale;
-    else
+    } else {
         scale = y_scale;
+    }
 
-    if (scale > 1.0 && !expand)
+    if (scale > 1.0 && !expand) {
         scale = 1.0;
-    if (scale < 1.0 && noShrink)
+    }
+    if (scale < 1.0 && noShrink) {
         scale = 1.0;
+    }
 
     cairo_matrix_init_identity(m);
     if (!noCenter) {
@@ -551,10 +565,11 @@ static cairo_status_t writeStream(void *closure, const unsigned char *data, unsi
 {
     FILE *file = (FILE *)closure;
 
-    if (fwrite(data, length, 1, file) == 1)
+    if (fwrite(data, length, 1, file) == 1) {
         return CAIRO_STATUS_SUCCESS;
-    else
+    } else {
         return CAIRO_STATUS_WRITE_ERROR;
+    }
 }
 
 static void beginDocument(GooString *inputFileName, GooString *outputFileName, double w, double h)
@@ -580,10 +595,12 @@ static void beginDocument(GooString *inputFileName, GooString *outputFileName, d
         if (ps || eps) {
 #ifdef CAIRO_HAS_PS_SURFACE
             surface = cairo_ps_surface_create_for_stream(writeStream, output_file, w, h);
-            if (level2)
+            if (level2) {
                 cairo_ps_surface_restrict_to_level(surface, CAIRO_PS_LEVEL_2);
-            if (eps)
+            }
+            if (eps) {
                 cairo_ps_surface_set_eps(surface, 1);
+            }
             if (duplex) {
                 cairo_ps_surface_dsc_comment(surface, "%%Requirements: duplex");
                 cairo_ps_surface_dsc_begin_setup(surface);
@@ -624,8 +641,9 @@ static void beginPage(double *w, double *h)
         }
 
 #ifdef CAIRO_HAS_PDF_SURFACE
-        if (pdf)
+        if (pdf) {
             cairo_pdf_surface_set_size(surface, *w, *h);
+        }
 #endif
 
 #ifdef CAIRO_HAS_WIN32_SURFACE
@@ -699,8 +717,9 @@ static void renderPage(PDFDoc *doc, CairoOutputDev *cairoOut, int pg, double pag
     }
 
     status = cairo_status(cr);
-    if (status)
+    if (status) {
         fprintf(stderr, "cairo error: %s\n", cairo_status_to_string(status));
+    }
     cairo_destroy(cr);
 }
 
@@ -720,8 +739,9 @@ static void endPage(GooString *imageFileName)
         writePageImage(imageFileName);
         cairo_surface_finish(surface);
         status = cairo_surface_status(surface);
-        if (status)
+        if (status) {
             fprintf(stderr, "cairo error: %s\n", cairo_status_to_string(status));
+        }
         cairo_surface_destroy(surface);
     }
 }
@@ -733,15 +753,17 @@ static void endDocument()
     if (printing) {
         cairo_surface_finish(surface);
         status = cairo_surface_status(surface);
-        if (status)
+        if (status) {
             fprintf(stderr, "cairo error: %s\n", cairo_status_to_string(status));
+        }
         cairo_surface_destroy(surface);
 #ifdef CAIRO_HAS_WIN32_SURFACE
         if (printToWin32)
             win32EndDocument();
 #endif
-        if (output_file)
+        if (output_file) {
             fclose(output_file);
+        }
     }
 }
 
@@ -776,12 +798,13 @@ static GooString *getImageFileName(GooString *outputFileName, int numDigits, int
         imageName->append(buf);
     }
     if (outputFileName->cmp("fd://0") != 0) {
-        if (png)
+        if (png) {
             imageName->append(".png");
-        else if (jpeg)
+        } else if (jpeg) {
             imageName->append(".jpg");
-        else if (tiff)
+        } else if (tiff) {
             imageName->append(".tif");
+        }
     }
 
     return imageName;
@@ -804,8 +827,9 @@ static GooString *getOutputFileName(GooString *fileName, GooString *outputName)
         return new GooString(outputName);
     }
 
-    if (printToWin32)
+    if (printToWin32) {
         return nullptr; // No output file means print to printer
+    }
 
     if (fileName->cmp("fd://0") == 0) {
         fprintf(stderr, "Error: an output filename or '-' must be supplied when the PDF file is stdin.\n");
@@ -841,14 +865,15 @@ static GooString *getOutputFileName(GooString *fileName, GooString *outputName)
     }
 
     // append new extension
-    if (ps)
+    if (ps) {
         name->append(".ps");
-    else if (eps)
+    } else if (eps) {
         name->append(".eps");
-    else if (pdf)
+    } else if (pdf) {
         name->append(".pdf");
-    else if (svg)
+    } else if (svg) {
         name->append(".svg");
+    }
 
     return name;
 }
@@ -875,7 +900,7 @@ int main(int argc, char *argv[])
     GooString *outputName = nullptr;
     GooString *outputFileName = nullptr;
     GooString *imageFileName = nullptr;
-    GooString *ownerPW, *userPW;
+    std::optional<GooString> ownerPW, userPW;
     CairoOutputDev *cairoOut;
     int pg, pg_num_len;
     double pg_w, pg_h, tmp, output_w, output_h;
@@ -899,10 +924,11 @@ int main(int argc, char *argv[])
         if (!printVersion) {
             printUsage("pdftocairo", "<PDF-file> [<output-file>]", argDesc);
         }
-        if (printVersion || printHelp)
+        if (printVersion || printHelp) {
             exit(0);
-        else
+        } else {
             exit(99);
+        }
     }
 
     num_outputs = (png ? 1 : 0) + (jpeg ? 1 : 0) + (tiff ? 1 : 0) + (ps ? 1 : 0) + (eps ? 1 : 0) + (pdf ? 1 : 0) + (printToWin32 ? 1 : 0) + (printdlg ? 1 : 0) + (svg ? 1 : 0);
@@ -914,10 +940,11 @@ int main(int argc, char *argv[])
         fprintf(stderr, "Error: use only one of the output format options (-png, -jpeg, -ps, -eps, -pdf, -printdlg, -print, -svg).\n");
         exit(99);
     }
-    if (png || jpeg || tiff)
+    if (png || jpeg || tiff) {
         printing = false;
-    else
+    } else {
         printing = true;
+    }
 
     if (printing) {
         checkInvalidPrintOption(mono, "-mono");
@@ -943,8 +970,9 @@ int main(int argc, char *argv[])
         checkInvalidImageOption(duplex, "-duplex");
     }
 
-    if (printing)
+    if (printing) {
         useCropBox = !noCrop;
+    }
 
     if (icc.c_str()[0] && !png) {
         fprintf(stderr, "Error: -icc may only be used with png output.\n");
@@ -952,8 +980,9 @@ int main(int argc, char *argv[])
     }
 
     if (antialias.getLength() > 0) {
-        if (!parseAntialiasOption())
+        if (!parseAntialiasOption()) {
             exit(99);
+        }
     }
 
     if (transp && !(png || tiff)) {
@@ -976,8 +1005,9 @@ int main(int argc, char *argv[])
             fprintf(stderr, "Error: -jpegopt may only be used with jpeg output.\n");
             exit(99);
         }
-        if (!parseJpegOptions())
+        if (!parseJpegOptions()) {
             exit(99);
+        }
     }
 
     if (strlen(tiffCompressionStr) > 0 && !tiff) {
@@ -989,8 +1019,9 @@ int main(int argc, char *argv[])
         fprintf(stderr, "Error: use only one of the 'level' options.\n");
         exit(99);
     }
-    if (!level2 && !level3)
+    if (!level2 && !level3) {
         level3 = true;
+    }
 
     if (eps && (origPageSizes || paperSize[0] || paperWidth > 0 || paperHeight > 0)) {
         fprintf(stderr, "Error: page size options may not be used with eps output.\n");
@@ -1012,13 +1043,15 @@ int main(int argc, char *argv[])
             exit(99);
         }
     }
-    if (origPageSizes || paperWidth < 0 || paperHeight < 0)
+    if (origPageSizes || paperWidth < 0 || paperHeight < 0) {
         usePDFPageSize = true;
-    else
+    } else {
         usePDFPageSize = false;
+    }
 
-    if (printdlg)
+    if (printdlg) {
         printToWin32 = true;
+    }
 
     globalParams = std::make_unique<GlobalParams>();
     if (quiet) {
@@ -1027,14 +1060,10 @@ int main(int argc, char *argv[])
 
     // open PDF file
     if (ownerPassword[0]) {
-        ownerPW = new GooString(ownerPassword);
-    } else {
-        ownerPW = nullptr;
+        ownerPW = GooString(ownerPassword);
     }
     if (userPassword[0]) {
-        userPW = new GooString(userPassword);
-    } else {
-        userPW = nullptr;
+        userPW = GooString(userPassword);
     }
 
     fileName = new GooString(argv[1]);
@@ -1042,10 +1071,11 @@ int main(int argc, char *argv[])
         delete fileName;
         fileName = new GooString("fd://0");
     }
-    if (argc == 3)
+    if (argc == 3) {
         outputName = new GooString(argv[2]);
-    else
+    } else {
         outputName = nullptr;
+    }
 
     outputFileName = getOutputFileName(fileName, outputName);
 
@@ -1091,12 +1121,15 @@ int main(int argc, char *argv[])
 #endif
 
     // get page range
-    if (firstPage < 1)
+    if (firstPage < 1) {
         firstPage = 1;
-    if (singleFile && lastPage < 1)
+    }
+    if (singleFile && lastPage < 1) {
         lastPage = firstPage;
-    if (lastPage < 1 || lastPage > doc->getNumPages())
+    }
+    if (lastPage < 1 || lastPage > doc->getNumPages()) {
         lastPage = doc->getNumPages();
+    }
 
     if (lastPage < firstPage) {
         fprintf(stderr, "Wrong page range given: the first page (%d) can not be after the last page (%d).\n", firstPage, lastPage);
@@ -1142,14 +1175,17 @@ int main(int argc, char *argv[])
     cairoOut->setDisplayProfile(profile);
 #endif
     cairoOut->startDoc(doc.get());
-    if (sz != 0)
+    if (sz != 0) {
         crop_w = crop_h = sz;
+    }
     pg_num_len = numberOfCharacters(doc->getNumPages());
     for (pg = firstPage; pg <= lastPage; ++pg) {
-        if (printOnlyEven && pg % 2 == 1)
+        if (printOnlyEven && pg % 2 == 1) {
             continue;
-        if (printOnlyOdd && pg % 2 == 0)
+        }
+        if (printOnlyOdd && pg % 2 == 0) {
             continue;
+        }
         if (useCropBox) {
             pg_w = doc->getPageCropWidth(pg);
             pg_h = doc->getPageCropHeight(pg);
@@ -1176,25 +1212,29 @@ int main(int argc, char *argv[])
         } else {
             if (x_scaleTo > 0) {
                 x_resolution = (72.0 * x_scaleTo) / pg_w;
-                if (y_scaleTo == -1)
+                if (y_scaleTo == -1) {
                     y_resolution = x_resolution;
+                }
             }
             if (y_scaleTo > 0) {
                 y_resolution = (72.0 * y_scaleTo) / pg_h;
-                if (x_scaleTo == -1)
+                if (x_scaleTo == -1) {
                     x_resolution = y_resolution;
+                }
             }
         }
         if (imageFileName) {
             delete imageFileName;
             imageFileName = nullptr;
         }
-        if (!printing)
+        if (!printing) {
             imageFileName = getImageFileName(outputFileName, pg_num_len, pg);
+        }
         getOutputSize(pg_w, pg_h, &output_w, &output_h);
 
-        if (pg == firstPage)
+        if (pg == firstPage) {
             beginDocument(fileName, outputFileName, output_w, output_h);
+        }
         beginPage(&output_w, &output_h);
         renderPage(doc.get(), cairoOut, pg, pg_w, pg_h, output_w, output_h);
         endPage(imageFileName);
@@ -1203,22 +1243,23 @@ int main(int argc, char *argv[])
 
     // clean up
     delete cairoOut;
-    if (fileName)
+    if (fileName) {
         delete fileName;
-    if (outputName)
+    }
+    if (outputName) {
         delete outputName;
-    if (outputFileName)
+    }
+    if (outputFileName) {
         delete outputFileName;
-    if (imageFileName)
+    }
+    if (imageFileName) {
         delete imageFileName;
-    if (ownerPW)
-        delete ownerPW;
-    if (userPW)
-        delete userPW;
+    }
 
 #ifdef USE_CMS
-    if (icc_data)
+    if (icc_data) {
         gfree(icc_data);
+    }
 #endif
 
     return 0;
